'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.getValidValue = exports.DOWN_ARROW = exports.UP_ARROW = exports.MERIDIAN_INPUT_CLASS = exports.MINUTES_INPUT_NAME = exports.MINUTES_INPUT_CLASS = exports.HOURS_INPUT_NAME = exports.HOURS_INPUT_CLASS = undefined;

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

var _KEY_INCREMENT;

var _react = require('react');

var React = _interopRequireWildcard(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _core = require('@js-joda/core');

var _Flex = require('../layout/Flex');

var _Flex2 = _interopRequireDefault(_Flex);

var _FlexItem = require('../layout/FlexItem');

var _FlexItem2 = _interopRequireDefault(_FlexItem);

var _Select = require('./Select');

var _Select2 = _interopRequireDefault(_Select);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var HOURS_INPUT_CLASS = exports.HOURS_INPUT_CLASS = 'timeInput-hours';
var HOURS_INPUT_NAME = exports.HOURS_INPUT_NAME = 'hour';
var MINUTES_INPUT_CLASS = exports.MINUTES_INPUT_CLASS = 'timeInput-minutes';
var MINUTES_INPUT_NAME = exports.MINUTES_INPUT_NAME = 'minute';
var MERIDIAN_INPUT_CLASS = exports.MERIDIAN_INPUT_CLASS = 'timeInput-meridian';

var UP_ARROW = exports.UP_ARROW = 38;
var DOWN_ARROW = exports.DOWN_ARROW = 40;
var KEY_INCREMENT = (_KEY_INCREMENT = {}, _defineProperty(_KEY_INCREMENT, UP_ARROW, 1), _defineProperty(_KEY_INCREMENT, DOWN_ARROW, -1), _KEY_INCREMENT);
var ADJUST_FIELD_MAP = {
	hour: _core.ChronoField.HOUR_OF_DAY,
	minute: _core.ChronoField.MINUTE_OF_HOUR
};
var EMPTY_VALS = { hour: '', minute: '', meridian: '0' };
var TIME_RE = /(?:[01]\d|2[0-3]):[0-5][0-9]/; // valid 'HH:mm' string values

// get indivdual { hour, minute, meridian } values as strings from 'HH:mm" value
var getValueComponents = function getValueComponents(is24Hr, value) {
	if (!value || !TIME_RE.test(value)) {
		// empty or invalid
		return EMPTY_VALS;
	}
	var localTime = _core.LocalTime.parse(value);

	var _localTime$toString$s = localTime.toString().split(':'),
	    _localTime$toString$s2 = _slicedToArray(_localTime$toString$s, 2),
	    hourString = _localTime$toString$s2[0],
	    minuteString = _localTime$toString$s2[1];

	return {
		hour: is24Hr ? hourString : localTime.get(_core.ChronoField.CLOCK_HOUR_OF_AMPM).toString(),
		minute: minuteString,
		meridian: localTime.get(_core.ChronoField.AMPM_OF_DAY).toString() // '0' or '1'
	};
};

/*
 * Given a maximum value, return the part of the string value that is acceptable.
 * This function is useful for accepting a stream of user input and only 'reading'
 * the most recent valid value that has been entered
 * getValidValue(10, '0123') === 3;
 * getValidValue(10, '01234') === 4;
 * getValidValue(100, '0123456') === 56
 * getValidValue(500, '0123456') === 456
 */
var getValidValue = exports.getValidValue = function getValidValue(max, value) {
	var maxDigits = max.toString().length;
	var value2digit = parseInt(value.slice(-maxDigits), 10);
	return value2digit > max ? parseInt(value.slice(-(maxDigits - 1)), 10) : value2digit;
};

/*
 * **IMPORTANT**: In general, consumers should never use this component directly.
 * Instead, use `<InputTime>`, which will delegate to this component in browsers
 * that do not support `<input type="time" />` but will otherwise use the more-standard
 * input
 *
 * FieldsetTime is a 3-input component to provide 'HH:mm' value to `onChange`
 * - used for browsers that don't support <input type="time" />
 *
 * Cool features:
 * - keyboard up/down support for hour/minute inputs (hold shift for +10 increment)
 * - correct hour/meridian wrapping when changing minute/hour
 * - no explicit input length limit, but only the most recent valid number input
 *   will be accepted/displayed (see getValidValue docs above)
 */

var FieldsetTime = function (_React$PureComponent) {
	_inherits(FieldsetTime, _React$PureComponent);

	function FieldsetTime() {
		var _ref;

		var _temp, _this, _ret;

		_classCallCheck(this, FieldsetTime);

		for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
			args[_key] = arguments[_key];
		}

		return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref = FieldsetTime.__proto__ || Object.getPrototypeOf(FieldsetTime)).call.apply(_ref, [this].concat(args))), _this), _this.onHourChange = function (e) {
			var validValue = getValidValue(_this.props.is24Hr ? 23 : 12, e.target.value);
			_this.changeField('hour', validValue);
		}, _this.onMinuteChange = function (e) {
			var validValue = getValidValue(59, e.target.value);
			_this.changeField('minute', validValue);
		}, _this.onMeridianChange = function (e) {
			if (!_this.props.value || _this.props.is24Hr) {
				return;
			}
			var localTime = _core.LocalTime.parse(_this.props.value);
			var meridian = parseInt(e.target.value, 10);
			_this.props.onChange(localTime.with(_core.ChronoField.AMPM_OF_DAY, meridian).toString());
		}, _this.onNumberKeyDown = function (e) {
			if (!KEY_INCREMENT[e.keyCode]) {
				return;
			}
			e.preventDefault(); // don't do anything but what I tell you
			var stepMultiplier = e.shiftKey ? 10 : 1; // hold shift for fast increment
			var stepSize = KEY_INCREMENT[e.keyCode] * stepMultiplier;
			var field = e.currentTarget.name; // 'hour' or 'minute'
			var currentTime = _this.props.value ? _core.LocalTime.parse(_this.props.value) : _core.LocalTime.of(0, 0, 0); // empty value is ok - just start incrementing from 00:00

			var newTimeFields = {
				hour: currentTime.hour(),
				minute: currentTime.minute()
			};
			newTimeFields[field] = newTimeFields[field] + stepSize;
			// wrap the hour when minute reaches boundaries
			if (newTimeFields.minute >= 60) {
				newTimeFields.hour = newTimeFields.hour + 1;
			}
			if (newTimeFields.minute < 0) {
				newTimeFields.hour = newTimeFields.hour - 1;
			}

			// trigger change with positive, modulated hour/minute values
			var newTime = _core.LocalTime.of((newTimeFields.hour + 24) % 24, (newTimeFields.minute + 60) % 60, 0);
			_this.props.onChange(newTime.toString());
		}, _temp), _possibleConstructorReturn(_this, _ret);
	}

	_createClass(FieldsetTime, [{
		key: 'changeField',
		value: function changeField(fieldName, newValue) {
			var _props = this.props,
			    value = _props.value,
			    onChange = _props.onChange,
			    is24Hr = _props.is24Hr;

			var currentTime = value ? _core.LocalTime.parse(value) : _core.LocalTime.of(0, 0, 0);
			if (Number.isNaN(newValue)) {
				// invalid value, so just force re-set to currentTime
				onChange(currentTime.toString());
				return;
			}
			// set the currentTime field corresponding to hour/minute
			var adjustField = ADJUST_FIELD_MAP[fieldName];
			var newTime = currentTime.with(adjustField, newValue);
			if (is24Hr) {
				onChange(newTime.toString());
				return;
			}
			onChange(newTime.with(_core.ChronoField.AMPM_OF_DAY, currentTime.get(_core.ChronoField.AMPM_OF_DAY)).toString());
		}

		// selects text when the hour or minute input gets focus

	}, {
		key: 'selectInputText',
		value: function selectInputText(e) {
			e.currentTarget.select();
		}

		// handler for AM/PM change - trigger onChange callback with new hour offset


		// Handle up/down arrow behavior in hour/minute fields

	}, {
		key: 'render',
		value: function render() {
			var _props2 = this.props,
			    id = _props2.id,
			    error = _props2.error,
			    required = _props2.required,
			    disabled = _props2.disabled,
			    name = _props2.name,
			    is24Hr = _props2.is24Hr,
			    value = _props2.value;


			var classNames = {
				fauxInput: (0, _classnames2.default)('fauxInput fauxInput--time', {
					disabled: disabled,
					error: error
				}),
				meridian: (0, _classnames2.default)(MERIDIAN_INPUT_CLASS, 'flush--all border--none field--reset padding--left', {
					disabled: disabled,
					error: error
				})
			};
			var displayId = id || name;

			var _getValueComponents = getValueComponents(is24Hr, value),
			    hour = _getValueComponents.hour,
			    minute = _getValueComponents.minute,
			    meridian = _getValueComponents.meridian;

			return React.createElement(
				'fieldset',
				{ className: classNames.fauxInput },
				React.createElement(
					_Flex2.default,
					{ noGutters: true },
					React.createElement(
						_FlexItem2.default,
						{ shrink: true },
						React.createElement('input', {
							type: 'number',
							pattern: '\\d*',
							id: displayId + '-hour',
							name: HOURS_INPUT_NAME,
							min: is24Hr ? 0 : 1,
							max: is24Hr ? 23 : 12,
							required: required,
							disabled: disabled,
							className: 'field--reset align--center ' + HOURS_INPUT_CLASS,
							onMouseUp: this.selectInputText,
							onChange: this.onHourChange,
							onKeyDown: this.onNumberKeyDown,
							value: hour,
							placeholder: '--'
						}),
						' '
					),
					React.createElement(
						_FlexItem2.default,
						{ shrink: true, className: 'align--center' },
						':'
					),
					React.createElement(
						_FlexItem2.default,
						{ shrink: true },
						React.createElement('input', {
							type: 'number',
							pattern: '\\d*',
							id: displayId + '-minute',
							name: MINUTES_INPUT_NAME,
							min: 0,
							max: 59,
							required: required,
							disabled: disabled,
							className: 'field--reset align--center ' + MINUTES_INPUT_CLASS,
							onMouseUp: this.selectInputText,
							onChange: this.onMinuteChange,
							onKeyDown: this.onNumberKeyDown,
							value: minute,
							placeholder: '--'
						})
					),
					!is24Hr && React.createElement(
						_FlexItem2.default,
						{
							shrink: true,
							className: 'timeInput-meridianContainer display--flex flex--column flex--center'
						},
						React.createElement(
							_Select2.default,
							{
								id: displayId + '-meridian',
								name: 'mwc-meridian',
								className: classNames.meridian,
								disabled: disabled,
								value: meridian.toString() // 0 or 1
								, onChange: this.onMeridianChange
							},
							React.createElement(
								'option',
								{ value: '0' },
								'AM'
							),
							React.createElement(
								'option',
								{ value: '1' },
								'PM'
							)
						)
					)
				)
			);
		}
	}]);

	return FieldsetTime;
}(React.PureComponent);

FieldsetTime.defaultProps = { is24Hr: true };
exports.default = FieldsetTime;
FieldsetTime.__docgenInfo = {
	'description': '',
	'methods': [{
		'name': 'onHourChange',
		'docblock': null,
		'modifiers': [],
		'params': [{
			'name': 'e',
			'type': {
				'name': 'SyntheticInputEvent',
				'elements': [{
					'name': 'HTMLInputElement'
				}],
				'raw': 'SyntheticInputEvent<HTMLInputElement>',
				'alias': 'SyntheticInputEvent'
			}
		}],
		'returns': null
	}, {
		'name': 'onMinuteChange',
		'docblock': null,
		'modifiers': [],
		'params': [{
			'name': 'e',
			'type': {
				'name': 'SyntheticInputEvent',
				'elements': [{
					'name': 'HTMLInputElement'
				}],
				'raw': 'SyntheticInputEvent<HTMLInputElement>',
				'alias': 'SyntheticInputEvent'
			}
		}],
		'returns': null
	}, {
		'name': 'changeField',
		'docblock': null,
		'modifiers': [],
		'params': [{
			'name': 'fieldName',
			'type': {
				'name': 'string'
			}
		}, {
			'name': 'newValue',
			'type': {
				'name': 'number'
			}
		}],
		'returns': null
	}, {
		'name': 'selectInputText',
		'docblock': null,
		'modifiers': [],
		'params': [{
			'name': 'e',
			'type': {
				'name': 'SyntheticEvent',
				'elements': [{
					'name': 'HTMLInputElement'
				}],
				'raw': 'SyntheticEvent<HTMLInputElement>',
				'alias': 'SyntheticEvent'
			}
		}],
		'returns': null
	}, {
		'name': 'onMeridianChange',
		'docblock': null,
		'modifiers': [],
		'params': [{
			'name': 'e',
			'type': {
				'name': 'SyntheticInputEvent',
				'elements': [{
					'name': 'HTMLInputElement'
				}],
				'raw': 'SyntheticInputEvent<HTMLInputElement>',
				'alias': 'SyntheticInputEvent'
			}
		}],
		'returns': null
	}, {
		'name': 'onNumberKeyDown',
		'docblock': null,
		'modifiers': [],
		'params': [{
			'name': 'e',
			'type': {
				'name': 'SyntheticKeyboardEvent',
				'elements': [{
					'name': 'HTMLInputElement'
				}],
				'raw': 'SyntheticKeyboardEvent<HTMLInputElement>',
				'alias': 'SyntheticKeyboardEvent'
			}
		}],
		'returns': null
	}],
	'displayName': 'FieldsetTime',
	'props': {
		'is24Hr': {
			'defaultValue': {
				'value': 'true',
				'computed': false
			},
			'flowType': {
				'name': 'boolean'
			},
			'required': false,
			'description': ''
		},
		'value': {
			'flowType': {
				'name': 'string'
			},
			'required': true,
			'description': ''
		},
		'disabled': {
			'flowType': {
				'name': 'boolean'
			},
			'required': false,
			'description': ''
		},
		'error': {
			'flowType': {
				'name': 'union',
				'raw': 'string | boolean',
				'elements': [{
					'name': 'string'
				}, {
					'name': 'boolean'
				}]
			},
			'required': false,
			'description': ''
		},
		'onChange': {
			'flowType': {
				'name': 'signature',
				'type': 'function',
				'raw': 'string => void',
				'signature': {
					'arguments': [{
						'name': '',
						'type': {
							'name': 'string'
						}
					}],
					'return': {
						'name': 'void'
					}
				}
			},
			'required': true,
			'description': ''
		}
	}
};
//# sourceMappingURL=FieldsetTime.js.map