'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.getRemainingCharacters = exports.getFormFieldState = undefined;

var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _Icon = require('@meetup/swarm-components/lib/Icon');

var _Icon2 = _interopRequireDefault(_Icon);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _withErrorList = require('../utils/components/withErrorList');

var _withErrorList2 = _interopRequireDefault(_withErrorList);

var _DeprecationWarning = require('../utils/components/DeprecationWarning');

var _DeprecationWarning2 = _interopRequireDefault(_DeprecationWarning);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }
// $FlowFixMe


var getFormFieldState = exports.getFormFieldState = function getFormFieldState(props) {
	var state = 'default';

	if (props.disabled) {
		state = 'disabled';
	} else if (props.error) {
		state = 'error';
	}

	return state;
};

var getRemainingCharacters = exports.getRemainingCharacters = function getRemainingCharacters(maxLength) {
	var charLength = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
	return maxLength - charLength;
};

var CharCount = function CharCount(props) {
	var maxLength = props.maxLength,
	    _props$charLength = props.charLength,
	    charLength = _props$charLength === undefined ? 0 : _props$charLength,
	    other = _objectWithoutProperties(props, ['maxLength', 'charLength']);

	return _react2.default.createElement(
		'p',
		_extends({ 'data-swarm-textarea-char-count': true, className: 'text--tiny' }, other),
		getRemainingCharacters(maxLength, charLength)
	);
};

var hasMaxLengthError = function hasMaxLengthError() {
	var maxLength = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;
	var charLength = arguments[1];
	return !!maxLength && charLength > maxLength;
};

/**
 * @module TextInput
 */
var SwarmTextInput = function SwarmTextInput(props) {
	var type = props.type,
	    name = props.name,
	    error = props.error,
	    isSearch = props.isSearch,
	    pattern = props.pattern,
	    disabled = props.disabled,
	    id = props.id,
	    iconShape = props.iconShape,
	    _props$value = props.value,
	    value = _props$value === undefined ? '' : _props$value,
	    maxLength = props.maxLength,
	    currencyLabel = props.currencyLabel,
	    className = props.className,
	    currencyLabelStyle = props.currencyLabelStyle,
	    other = _objectWithoutProperties(props, ['type', 'name', 'error', 'isSearch', 'pattern', 'disabled', 'id', 'iconShape', 'value', 'maxLength', 'currencyLabel', 'className', 'currencyLabelStyle']);

	var wrapperState = iconShape ? 'icon' : 'default';
	var charLength = value.length;
	var inputState = getFormFieldState(_extends({}, props, {
		error: error || hasMaxLengthError(maxLength, charLength)
	}));

	var _useState = (0, _react.useState)(false),
	    _useState2 = _slicedToArray(_useState, 2),
	    showPassword = _useState2[0],
	    setShowPassword = _useState2[1];

	var togglePassword = (0, _react.useCallback)(function () {
		setShowPassword(!showPassword);
	}, [showPassword]);

	if (type === 'password') {
		return _react2.default.createElement(
			'div',
			{ 'data-swarm-text-input-wrapper': wrapperState },
			_react2.default.createElement('input', _extends({
				'data-swarm-text-input': inputState,
				type: showPassword ? 'text' : 'password',
				name: name,
				disabled: disabled,
				id: id,
				value: value
			}, other)),
			_react2.default.createElement(
				'span',
				{
					onClick: togglePassword,
					'data-swarm-input-icon': 'xs',
					'data-swarm-position-right': true,
					'data-swarm-focusable': true
				},
				_react2.default.createElement(_Icon2.default, {
					shape: showPassword ? 'eye-visible' : 'eye-hidden',
					'aria-hidden': true
				})
			),
			maxLength && _react2.default.createElement(CharCount, { maxLength: maxLength, charLength: charLength })
		);
	}

	return _react2.default.createElement(
		'div',
		{
			'data-swarm-text-input-wrapper': wrapperState,
			className: (0, _classnames2.default)({ 'text-input-container': !!currencyLabel })
		},
		_react2.default.createElement('input', _extends({
			'data-swarm-text-input': inputState,
			type: isSearch ? 'search' : 'text',
			name: name,
			pattern: pattern,
			disabled: disabled,
			id: id,
			className: (0, _classnames2.default)(className, {
				'input-with-currency-label': !!currencyLabel
			}),
			value: value
		}, other)),
		iconShape && _react2.default.createElement(
			'span',
			{ 'data-swarm-input-icon': iconShape },
			_react2.default.createElement(_Icon2.default, { shape: iconShape, 'aria-hidden': true })
		),
		maxLength && _react2.default.createElement(CharCount, { maxLength: maxLength, charLength: charLength }),
		currencyLabel && _react2.default.createElement(
			'span',
			{ className: (0, _classnames2.default)('currency-label', currencyLabelStyle) },
			currencyLabel
		)
	);
};

exports.default = (0, _withErrorList2.default)((0, _DeprecationWarning2.default)(SwarmTextInput));
SwarmTextInput.__docgenInfo = {
	'description': '@module TextInput',
	'methods': [],
	'props': {
		'type': {
			'flowType': {
				'name': 'string'
			},
			'required': false,
			'description': 'Input type'
		},
		'disabled': {
			'flowType': {
				'name': 'boolean'
			},
			'required': false,
			'description': 'Whether the input should be interactive.'
		},
		'error': {
			'flowType': {
				'name': 'boolean'
			},
			'required': false,
			'description': 'Whether the field has an error.'
		},
		'id': {
			'flowType': {
				'name': 'string'
			},
			'required': true,
			'description': 'An identifier for the input.'
		},
		'isSearch': {
			'flowType': {
				'name': 'boolean'
			},
			'required': false,
			'description': 'Whether the input is a search field.'
		},
		'name': {
			'flowType': {
				'name': 'string'
			},
			'required': true,
			'description': 'Name for the input.'
		},
		'pattern': {
			'flowType': {
				'name': 'string'
			},
			'required': false,
			'description': 'A regular expression that the input\'s value is checked against on form submission.'
		},
		'value': {
			'flowType': {
				'name': 'string'
			},
			'required': false,
			'description': 'Value of input.'
		},
		'iconShape': {
			'flowType': {
				'name': 'string'
			},
			'required': false,
			'description': 'Name of icon to render in the input'
		},
		'iconSize': {
			'flowType': {
				'name': 'union',
				'raw': '\'xxs\' | \'xs\' | \'s\' | \'m\' | \'l\' | \'xl\' | \'xxl\'',
				'elements': [{
					'name': 'literal',
					'value': '\'xxs\''
				}, {
					'name': 'literal',
					'value': '\'xs\''
				}, {
					'name': 'literal',
					'value': '\'s\''
				}, {
					'name': 'literal',
					'value': '\'m\''
				}, {
					'name': 'literal',
					'value': '\'l\''
				}, {
					'name': 'literal',
					'value': '\'xl\''
				}, {
					'name': 'literal',
					'value': '\'xxl\''
				}]
			},
			'required': false,
			'description': 'Optional size for icon if `iconShape` is provided.\nDefault size is `xs`'
		},
		'maxLength': {
			'flowType': {
				'name': 'number'
			},
			'required': false,
			'description': 'max length of input field'
		},
		'currencyLabel': {
			'flowType': {
				'name': 'string'
			},
			'required': false,
			'description': 'currency label for price field'
		},
		'className': {
			'flowType': {
				'name': 'string'
			},
			'required': false,
			'description': ''
		},
		'defaultValue': {
			'flowType': {
				'name': 'string'
			},
			'required': false,
			'description': ''
		},
		'currencyLabelStyle': {
			'flowType': {
				'name': 'string'
			},
			'required': false,
			'description': ''
		}
	}
};
//# sourceMappingURL=SwarmTextInput.js.map