'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.ACCORDION_LABEL_CLASS = exports.ACTIVEPANEL_CLASS = exports.PANEL_CLASS = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _Chunk = require('../layout/Chunk');

var _Chunk2 = _interopRequireDefault(_Chunk);

var _Flex = require('../layout/Flex');

var _Flex2 = _interopRequireDefault(_Flex);

var _FlexItem = require('../layout/FlexItem');

var _FlexItem2 = _interopRequireDefault(_FlexItem);

var _Icon = require('../media/Icon');

var _Icon2 = _interopRequireDefault(_Icon);

var _ToggleSwitch = require('../forms/ToggleSwitch');

var _ToggleSwitch2 = _interopRequireDefault(_ToggleSwitch);

var _LockedBadge = require('../forms/LockedBadge');

var _LockedBadge2 = _interopRequireDefault(_LockedBadge);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var PANEL_CLASS = exports.PANEL_CLASS = 'accordionPanel';
var ACTIVEPANEL_CLASS = exports.ACTIVEPANEL_CLASS = 'accordionPanel--active';
var ACCORDION_LABEL_CLASS = exports.ACCORDION_LABEL_CLASS = 'accordionPanel-label';

/**
 * @module AccordionPanel
 */

var AccordionPanel = function (_React$Component) {
	_inherits(AccordionPanel, _React$Component);

	function AccordionPanel(props) {
		_classCallCheck(this, AccordionPanel);

		var _this = _possibleConstructorReturn(this, (AccordionPanel.__proto__ || Object.getPrototypeOf(AccordionPanel)).call(this, props));

		_this._handleToggle = _this._handleToggle.bind(_this);
		_this.onKeyUp = _this.onKeyUp.bind(_this);
		_this.onToggleClick = _this.onToggleClick.bind(_this);
		_this.onTransitionEnd = _this.onTransitionEnd.bind(_this);
		_this.handleLockedLabelClick = _this.handleLockedLabelClick.bind(_this);

		_this.state = {
			height: props.isOpen ? 'auto' : '0px'
		};
		return _this;
	}

	/**
  * @parm {Boolean} isOpen
  * @parm {Ref} contentEl - element ref
  * @returns {Object} inline styles
  */


	_createClass(AccordionPanel, [{
		key: 'getPanelStyle',
		value: function getPanelStyle(isOpen, contentEl) {
			var style = { height: '0px' };

			// set height to 0
			if (!isOpen || !contentEl) {
				return style;
			}

			// set height to {n}px
			style.height = contentEl.getBoundingClientRect().height + 'px';
			return style;
		}

		/**
   *
   * @description calls the AccordionPanelGroups's callback to toggle open state
   * and render the `AccordionPanel` open or closed, sets height in state
   * @param {Event} e - the event object
   * @returns {undefined}
   */

	}, {
		key: '_handleToggle',
		value: function _handleToggle(e) {
			e.preventDefault();

			var _props = this.props,
			    isOpen = _props.isOpen,
			    setClickedPanel = _props.setClickedPanel,
			    onClickCallback = _props.onClickCallback,
			    panelIndex = _props.panelIndex,
			    disableAndOpen = _props.disableAndOpen,
			    isDisabledPanelOpen = _props.isDisabledPanelOpen,
			    isLocked = _props.isLocked;

			if (isLocked) return;
			if (disableAndOpen) {
				setClickedPanel && setClickedPanel(e, {
					panelIndex: panelIndex,
					isDisabledPanelOpen: true
				});
				return this.getPanelStyle(isDisabledPanelOpen, this.contentEl);
			}
			setClickedPanel && setClickedPanel(e, {
				panelIndex: panelIndex,
				isOpen: !isOpen
			});
			this.getPanelStyle(!isOpen, this.contentEl);
			onClickCallback && onClickCallback(e, !isOpen);
		}
	}, {
		key: 'onToggleClick',
		value: function onToggleClick(e) {
			e.preventDefault();

			this.props.onToggleClick ? this.props.onToggleClick(e) : this._handleToggle(e);
		}

		/**
   * @description allows the AccordionPanel content to be toggled with the "Enter" and "space" keys
   * @returns {undefined}
   */

	}, {
		key: 'onKeyUp',
		value: function onKeyUp(e) {
			var isActivatingButton = [' ', 'Enter'].some(function (key) {
				return e.key === key;
			});

			if (isActivatingButton) {
				this._handleToggle(e);
			}
		}

		/**
   * @description forceUpdate allows us to calculate height again now that contentEl is set
   * @returns {undefined}
   */

	}, {
		key: 'componentDidMount',
		value: function componentDidMount() {
			this.forceUpdate();
		}

		/**
   * @description set height state when the panel receives a change
   * @returns {undefined}
   */

	}, {
		key: 'UNSAFE_componentWillReceiveProps',
		value: function UNSAFE_componentWillReceiveProps(nextProps) {
			var _this2 = this;

			if (nextProps.isOpen !== this.props.isOpen) {
				this.setState(function () {
					return _this2.getPanelStyle(!nextProps.isOpen, _this2.contentEl);
				}, function () {
					setTimeout(function () {
						_this2.setState(function () {
							return _this2.getPanelStyle(nextProps.isOpen, _this2.contentEl);
						});
					}, 1);
				});
			}
		}

		/**
   * @returns {String} icon shape
   */

	}, {
		key: 'getIconShape',
		value: function getIconShape() {
			var _props2 = this.props,
			    indicatorIcon = _props2.indicatorIcon,
			    indicatorIconActive = _props2.indicatorIconActive;


			return this.props.isOpen && indicatorIconActive ? indicatorIconActive : indicatorIcon;
		}

		/**
   * @returns undefined
   */

	}, {
		key: 'onTransitionEnd',
		value: function onTransitionEnd() {
			if (this.props.isOpen) {
				this.setState(function () {
					return {
						height: 'auto'
					};
				});
			}
		}
	}, {
		key: 'handleLockedLabelClick',
		value: function handleLockedLabelClick(e) {
			e.preventDefault();

			this.props.onLockedLabelClick(e);
		}
	}, {
		key: 'render',
		value: function render() {
			var _cx,
			    _this3 = this;

			var _props3 = this.props,
			    panelContent = _props3.panelContent,
			    panelIndex = _props3.panelIndex,
			    label = _props3.label,
			    isOpen = _props3.isOpen,
			    setClickedPanel = _props3.setClickedPanel,
			    onClickCallback = _props3.onClickCallback,
			    indicatorAlign = _props3.indicatorAlign,
			    indicatorIcon = _props3.indicatorIcon,
			    indicatorIconActive = _props3.indicatorIconActive,
			    indicatorIconSize = _props3.indicatorIconSize,
			    indicatorSwitch = _props3.indicatorSwitch,
			    classNamesActive = _props3.classNamesActive,
			    className = _props3.className,
			    onToggleClick = _props3.onToggleClick,
			    disableAndOpen = _props3.disableAndOpen,
			    isDisabledPanelOpen = _props3.isDisabledPanelOpen,
			    isLocked = _props3.isLocked,
			    lockedLabel = _props3.lockedLabel,
			    onLockedLabelClick = _props3.onLockedLabelClick,
			    other = _objectWithoutProperties(_props3, ['panelContent', 'panelIndex', 'label', 'isOpen', 'setClickedPanel', 'onClickCallback', 'indicatorAlign', 'indicatorIcon', 'indicatorIconActive', 'indicatorIconSize', 'indicatorSwitch', 'classNamesActive', 'className', 'onToggleClick', 'disableAndOpen', 'isDisabledPanelOpen', 'isLocked', 'lockedLabel', 'onLockedLabelClick']);

			var classNames = {
				accordionPanel: (0, _classnames2.default)('padding--bottom padding--top', PANEL_CLASS, (_cx = {}, _defineProperty(_cx, ACTIVEPANEL_CLASS, isOpen), _defineProperty(_cx, classNamesActive, isOpen && classNamesActive), _cx), className),
				trigger: (0, _classnames2.default)(className, ACCORDION_LABEL_CLASS, 'display--block span--100'),
				content: (0, _classnames2.default)('accordionPanel-animator', {
					'accordionPanel-animator--collapse': !isOpen
				}),
				icon: (0, _classnames2.default)('indicator', {
					'indicator--animateActive': this.getIconShape() == 'chevron-down' && isOpen
				})
			};

			var isLabelString = label && typeof label == 'string';
			var panelId = isLabelString ? label.replace(/\s+/g, '').toLowerCase() : panelIndex;

			return _react2.default.createElement(
				'div',
				null,
				_react2.default.createElement(
					'div',
					{
						'aria-controls': 'panel-' + panelId,
						className: classNames.trigger,
						tabIndex: 0,
						onKeyUp: this.onKeyUp,
						onClick: this.onToggleClick
					},
					_react2.default.createElement(
						_Flex2.default,
						_extends({
							className: classNames.accordionPanel,
							rowReverse: indicatorAlign === 'left' && 'all',
							tabIndex: -1,
							align: 'center'
						}, other),
						isLocked ? _react2.default.createElement(
							_Flex2.default,
							{
								wrap: true,
								direction: 'column',
								className: 'accordionPanel-locked'
							},
							_react2.default.createElement(
								_FlexItem2.default,
								{
									id: 'label-' + panelId,
									className: 'accordionPanel-locked-panel-label',
									shrink: true
								},
								label
							),
							_react2.default.createElement(_LockedBadge2.default, {
								label: lockedLabel,
								onClick: onLockedLabelClick
							})
						) : _react2.default.createElement(
							_FlexItem2.default,
							{ id: 'label-' + panelId },
							label
						),
						_react2.default.createElement(
							_FlexItem2.default,
							{
								className: 'accordionPanel-icon',
								onClick: this.onToggleClick,
								shrink: true
							},
							!indicatorSwitch && indicatorIcon ? _react2.default.createElement(_Icon2.default, {
								shape: this.getIconShape(),
								size: indicatorIconSize,
								className: classNames.icon
							}) : _react2.default.createElement(_ToggleSwitch2.default, {
								tabIndex: '-1',
								isActive: isOpen && !disableAndOpen,
								disabled: !!onToggleClick || !!disableAndOpen,
								id: 'switch-' + panelId,
								labelledBy: 'label-' + panelId,
								name: panelId,
								onClick: this.onToggleClick
							})
						)
					)
				),
				_react2.default.createElement(
					_Chunk2.default,
					{
						role: 'tabpanel',
						id: 'panel-' + panelId,
						'aria-labelledby': 'label-' + panelId,
						'aria-hidden': !isOpen,
						className: classNames.content,
						style: { height: this.state.height },
						onTransitionEnd: this.onTransitionEnd
					},
					_react2.default.createElement(
						'div',
						{
							className: 'accordionPanel-content',
							ref: function ref(div) {
								_this3.contentEl = div;
							}
						},
						panelContent
					)
				)
			);
		}
	}]);

	return AccordionPanel;
}(_react2.default.Component);

AccordionPanel.defaultProps = {
	isOpen: false,
	indicatorAlign: 'right',
	indicatorIcon: 'chevron-down',
	indicatorIconSize: 'xs'
};

AccordionPanel.propTypes = {
	/** zero-indexed position of the panel */
	panelIndex: _propTypes2.default.number,

	/** Class names to add to the panel wrapper when the panel is open */
	classNamesActive: _propTypes2.default.string,

	/** Whether the panel is open */
	isOpen: _propTypes2.default.oneOf([null, true, false]),

	/** The content to render inside the detail area of an expanded panel */
	panelContent: _propTypes2.default.element,

	/** A function used to set the clicked panel to it's opened state */
	setClickedPanel: _propTypes2.default.func,

	/** A callback that happens after the panel has been toggled */
	onClickCallback: _propTypes2.default.func,

	/** Content to render in the part of the panel that is always visible (does not include indicator icon or switch) */
	label: _propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.element]).isRequired,

	/** Class names to add to the wrapper of the panel label and indicator */
	className: _propTypes2.default.string,

	/** Which side of each panel that the icon or indicator switch renders on */
	indicatorAlign: _propTypes2.default.string,

	/** Shape name of the icon to render as an indicator for closed panels */
	indicatorIcon: _propTypes2.default.string,

	/** Shape name of the icon to render as an indicator for opened panels */
	indicatorIconActive: _propTypes2.default.string,

	/** Size key for the icon rendered for open and closed indicators */
	indicatorIconSize: _propTypes2.default.oneOf(['xs', 's', 'm', 'l', 'xl']),

	/** Whether to use a ToggleSwitch as an indicator instead of an icon */
	indicatorSwitch: _propTypes2.default.bool,

	/** Prevent ToggleSwitch active but show content after click  */
	disableAndOpen: _propTypes2.default.bool,

	/** Whether the panel is locked due to some conditional requirements */
	isLocked: _propTypes2.default.bool,

	/** Label of CTA badge for unlocking the panel */
	lockedLabel: _propTypes2.default.string,

	/** A callback that happens after the locked label has been clicked  */
	onLockedLabelClick: _propTypes2.default.func
};

exports.default = AccordionPanel;
//# sourceMappingURL=AccordionPanel.js.map