'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.getNewPanelState = exports.ACCORDIONPANELGROUP_CLASS = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var ACCORDIONPANELGROUP_CLASS = exports.ACCORDIONPANELGROUP_CLASS = 'accordionPanelGroup';

/**
 * @description takes AccordionPanelGroup and AccordionPanel data and returns an array of new panel `isOpen` states
 * @param {Boolean} isMultiselect
 * @param {Array} statesList
 * @param {Object} clickedPanelData
 * @returns {Function} a Promise that maps statesList to an array of each panel's `isOpen` prop value
 */
var getNewPanelState = exports.getNewPanelState = function getNewPanelState(isMultiselect, statesList, clickedPanelData) {
	return statesList.map(function (panelState, i) {
		var defaultState = isMultiselect ? panelState : false;

		// not the panel that was clicked
		if (clickedPanelData.panelIndex !== i) {
			return defaultState;
		}

		return clickedPanelData.isDisabledPanelOpen || clickedPanelData.isOpen;
	});
};

/**
 * @module AccordionPanelGroup
 */

var AccordionPanelGroup = function (_React$Component) {
	_inherits(AccordionPanelGroup, _React$Component);

	function AccordionPanelGroup(props) {
		_classCallCheck(this, AccordionPanelGroup);

		var _this = _possibleConstructorReturn(this, (AccordionPanelGroup.__proto__ || Object.getPrototypeOf(AccordionPanelGroup)).call(this, props));

		_this.state = {
			panelStatesList: props.accordionPanels.map(function (panel) {
				return panel.props.isOpen || false;
			})
		};

		_this.handlePanelClick = _this.handlePanelClick.bind(_this);
		return _this;
	}

	/**
  * @param {Object} e
  * @param {Object} panelData
  * @returns undefined
  */


	_createClass(AccordionPanelGroup, [{
		key: 'handlePanelClick',
		value: function handlePanelClick(e, panelData) {
			var multiSelectable = this.props.multiSelectable;


			this.setState(function (prevState) {
				var panelStatesList = prevState.panelStatesList;

				var newPanelState = getNewPanelState(multiSelectable, panelStatesList, panelData);

				return { panelStatesList: newPanelState };
			});
		}
	}, {
		key: 'render',
		value: function render() {
			var _this2 = this;

			var _props = this.props,
			    accordionPanels = _props.accordionPanels,
			    panelContent = _props.panelContent,
			    indicatorAlign = _props.indicatorAlign,
			    indicatorIcon = _props.indicatorIcon,
			    indicatorIconActive = _props.indicatorIconActive,
			    indicatorIconSize = _props.indicatorIconSize,
			    indicatorSwitch = _props.indicatorSwitch,
			    multiSelectable = _props.multiSelectable,
			    className = _props.className,
			    isOpen = _props.isOpen,
			    other = _objectWithoutProperties(_props, ['accordionPanels', 'panelContent', 'indicatorAlign', 'indicatorIcon', 'indicatorIconActive', 'indicatorIconSize', 'indicatorSwitch', 'multiSelectable', 'className', 'isOpen']);

			var classNames = (0, _classnames2.default)(ACCORDIONPANELGROUP_CLASS, 'list', className);

			return _react2.default.createElement(
				'ul',
				_extends({
					role: 'tree',
					'aria-multiselectable': multiSelectable,
					className: classNames
				}, other),
				accordionPanels.map(function (panel, i) {
					return _react2.default.createElement(
						'li',
						{ key: i, className: 'list-item flush--top', role: 'treeitem' },
						_react2.default.cloneElement(panel, _extends({}, panel.props, {
							panelIndex: i,
							setClickedPanel: _this2.handlePanelClick,
							isOpen: _this2.state.panelStatesList[i],
							indicatorAlign: indicatorAlign,
							indicatorIcon: indicatorIcon,
							indicatorIconActive: indicatorIconActive,
							indicatorSwitch: indicatorSwitch,
							isDisabledPanelOpen: _this2.state.panelStatesList[i]
						}), panel.props.children)
					);
				})
			);
		}
	}]);

	return AccordionPanelGroup;
}(_react2.default.Component);

AccordionPanelGroup.defaultProps = {
	indicatorAlign: 'right',
	indicatorIcon: 'chevron-down',
	multiSelectable: true,
	indicatorIconSize: 'xs'
};

AccordionPanelGroup.propTypes = {
	/** Panels to render in a group */
	accordionPanels: _propTypes2.default.arrayOf(_propTypes2.default.element).isRequired,

	/** Whether more than one panel can be open at a time */
	multiSelectable: _propTypes2.default.bool,

	/** Which side of each panel that the icon or indicator switch renders on */
	indicatorAlign: _propTypes2.default.string,

	/** Shape name of the icon to render as an indicator for closed panels */
	indicatorIcon: _propTypes2.default.string,

	/** Shape name of the icon to render as an indicator for opened panels */
	indicatorIconActive: _propTypes2.default.string,

	/** Size key for the icon rendered for open and closed indicators */
	indicatorIconSize: _propTypes2.default.oneOf(['xs', 's', 'm', 'l', 'xl']),

	/** Whether to use a ToggleSwitch as an indicator instead of an icon */
	indicatorSwitch: _propTypes2.default.bool
};

exports.default = AccordionPanelGroup;
AccordionPanelGroup.__docgenInfo = {
	'description': '@module AccordionPanelGroup',
	'methods': [{
		'name': 'handlePanelClick',
		'docblock': '@param {Object} e\n@param {Object} panelData\n@returns undefined',
		'modifiers': [],
		'params': [{
			'name': 'e',
			'description': null,
			'type': {
				'name': 'Object'
			}
		}, {
			'name': 'panelData',
			'description': null,
			'type': {
				'name': 'Object'
			}
		}],
		'returns': {
			'description': 'undefined',
			'type': null
		},
		'description': null
	}],
	'displayName': 'AccordionPanelGroup',
	'props': {
		'indicatorAlign': {
			'defaultValue': {
				'value': '\'right\'',
				'computed': false
			},
			'type': {
				'name': 'string'
			},
			'required': false,
			'description': 'Which side of each panel that the icon or indicator switch renders on'
		},
		'indicatorIcon': {
			'defaultValue': {
				'value': '\'chevron-down\'',
				'computed': false
			},
			'type': {
				'name': 'string'
			},
			'required': false,
			'description': 'Shape name of the icon to render as an indicator for closed panels'
		},
		'multiSelectable': {
			'defaultValue': {
				'value': 'true',
				'computed': false
			},
			'type': {
				'name': 'bool'
			},
			'required': false,
			'description': 'Whether more than one panel can be open at a time'
		},
		'indicatorIconSize': {
			'defaultValue': {
				'value': '\'xs\'',
				'computed': false
			},
			'type': {
				'name': 'enum',
				'value': [{
					'value': '\'xs\'',
					'computed': false
				}, {
					'value': '\'s\'',
					'computed': false
				}, {
					'value': '\'m\'',
					'computed': false
				}, {
					'value': '\'l\'',
					'computed': false
				}, {
					'value': '\'xl\'',
					'computed': false
				}]
			},
			'required': false,
			'description': 'Size key for the icon rendered for open and closed indicators'
		},
		'accordionPanels': {
			'type': {
				'name': 'arrayOf',
				'value': {
					'name': 'element'
				}
			},
			'required': true,
			'description': 'Panels to render in a group'
		},
		'indicatorIconActive': {
			'type': {
				'name': 'string'
			},
			'required': false,
			'description': 'Shape name of the icon to render as an indicator for opened panels'
		},
		'indicatorSwitch': {
			'type': {
				'name': 'bool'
			},
			'required': false,
			'description': 'Whether to use a ToggleSwitch as an indicator instead of an icon'
		}
	}
};
//# sourceMappingURL=AccordionPanelGroup.js.map