'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.ModalComponent = exports.getModalPosition = exports.MARGIN_TOP_OFFSET = exports.DEFAULT_MARGIN_TOP = exports.MODAL_CLOSE_AREA_STICKYTRANSP = exports.MODAL_CLOSE_AREA_STICKY = exports.MODAL_CLOSE_BUTTON = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _focusTrapReact = require('focus-trap-react');

var _focusTrapReact2 = _interopRequireDefault(_focusTrapReact);

var _Icon = require('../media/Icon');

var _Icon2 = _interopRequireDefault(_Icon);

var _Button = require('../forms/Button');

var _Button2 = _interopRequireDefault(_Button);

var _Stripe = require('../layout/Stripe');

var _Stripe2 = _interopRequireDefault(_Stripe);

var _withLoading = require('../utils/components/withLoading');

var _withLoading2 = _interopRequireDefault(_withLoading);

var _designConstants = require('../utils/designConstants');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var MODAL_CLOSE_BUTTON = exports.MODAL_CLOSE_BUTTON = 'modal-closeButton';
var MODAL_CLOSE_AREA_STICKY = exports.MODAL_CLOSE_AREA_STICKY = 'modal-closeButtonContainer--sticky';
var MODAL_CLOSE_AREA_STICKYTRANSP = exports.MODAL_CLOSE_AREA_STICKYTRANSP = 'modal-closeButtonContainer--stickyTransparent';
var DEFAULT_MARGIN_TOP = exports.DEFAULT_MARGIN_TOP = '10vh';
var MARGIN_TOP_OFFSET = exports.MARGIN_TOP_OFFSET = 36;

/**
 * Gets `margin-top` value for vertically positioning the modal
 *
 * @param {String} scrollPosition window scroll position
 * @param {String} viewportHeight client height
 * @param {Boolean} isFullScreen true if the modal full screen
 * @param {Boolean} isFixedPosition true if the modal is on a fixed position screen
 * @param {Boolean} isMobileSize true if the viewport is below `medium` breakpoint
 *
 * @returns {String} CSS value for setting modal margin-top
 */
var getModalPosition = exports.getModalPosition = function getModalPosition(scrollPosition, viewportHeight, isFullScreen, isFixedPosition, isMobileSize) {
	// console.log('scrollPosition', scrollPosition);
	// console.log('viewportHeight', viewportHeight);
	// console.log('isFullScreen', isFullScreen);
	// console.log('isFixedPosition', isFixedPosition);
	// console.log('isMobileSize', isMobileSize);

	// full screen dialogs should be flush with top of the viewport
	if (isFullScreen) {
		return '0px';
	}

	if (isFixedPosition) {
		return isMobileSize ? scrollPosition : DEFAULT_MARGIN_TOP;
	}

	// for mobile-sized viewports, return the scroll position without a gutter
	if (isMobileSize) {
		return scrollPosition;
	}

	// set the margin-top based on scroll position unless user is above fold
	return scrollPosition > viewportHeight ? scrollPosition + MARGIN_TOP_OFFSET : DEFAULT_MARGIN_TOP;
};

/**
 * SQ2 Modal component
 * @see {@link http://meetup.github.io/sassquatch2/views.html#modals}
 * @module ModalComponent
 */

var ModalComponent = exports.ModalComponent = function (_React$Component) {
	_inherits(ModalComponent, _React$Component);

	function ModalComponent(props) {
		_classCallCheck(this, ModalComponent);

		var _this = _possibleConstructorReturn(this, (ModalComponent.__proto__ || Object.getPrototypeOf(ModalComponent)).call(this, props));

		_this.onDismiss = _this.onDismiss.bind(_this);
		_this.onKeyDown = _this.onKeyDown.bind(_this);

		_this.state = {
			topPosition: DEFAULT_MARGIN_TOP, // matches default margin-top in CSS
			isMobileSize: true
		};
		return _this;
	}

	_createClass(ModalComponent, [{
		key: 'onDismiss',
		value: function onDismiss(e) {
			e.stopPropagation();

			if (this.props.onDismiss) {
				this.props.onDismiss(e);
			}
		}
	}, {
		key: 'onKeyDown',
		value: function onKeyDown(e) {
			if (e.key === 'Escape') {
				this.onDismiss(e);
			}
		}
	}, {
		key: 'componentDidMount',
		value: function componentDidMount() {
			var _this2 = this;

			var handlePositioning = function handlePositioning() {
				_this2.setState({
					topPosition: getModalPosition(window.pageYOffset, Math.max(document.documentElement.clientHeight, window.innerHeight || 0), _this2.props.fullscreen, _this2.props.fixed, _this2.mediaQuery && !_this2.mediaQuery.matches),
					isMobileSize: _this2.mediaQuery && !_this2.mediaQuery.matches
				});
			};

			if (!this.props.fullscreen && typeof window.matchMedia != 'undefined') {
				this.mediaQuery = window.matchMedia(_designConstants.MEDIA_QUERIES.medium);

				this.handleMediaChange = function () {
					handlePositioning();
				};

				// fire on mount, _then_ listen for matchMedia changes
				this.handleMediaChange();
				this.mqListener = this.mediaQuery.addListener(this.handleMediaChange);
			} else if (this.props.fullscreen) {
				handlePositioning();
			}
		}
	}, {
		key: 'componentWillUnmount',
		value: function componentWillUnmount() {
			this.mediaQuery && this.mediaQuery.removeListener(this.handleMediaChange);
		}
	}, {
		key: 'render',
		value: function render() {
			var _cx;

			var _props = this.props,
			    className = _props.className,
			    children = _props.children,
			    fullscreen = _props.fullscreen,
			    fixed = _props.fixed,
			    heroBgColor = _props.heroBgColor,
			    heroBgImage = _props.heroBgImage,
			    heroContent = _props.heroContent,
			    hideHeroScrim = _props.hideHeroScrim,
			    inverted = _props.inverted,
			    closeArea = _props.closeArea,
			    stickyCloseArea = _props.stickyCloseArea,
			    initialFocus = _props.initialFocus,
			    focusTrapActive = _props.focusTrapActive,
			    _props$loadingProps = _props.loadingProps,
			    loadingProps = _props$loadingProps === undefined ? {} : _props$loadingProps,
			    isLoading = _props.isLoading,
			    other = _objectWithoutProperties(_props, ['className', 'children', 'fullscreen', 'fixed', 'heroBgColor', 'heroBgImage', 'heroContent', 'hideHeroScrim', 'inverted', 'closeArea', 'stickyCloseArea', 'initialFocus', 'focusTrapActive', 'loadingProps', 'isLoading']);

			delete other.onDismiss; // onDismiss is consumed in this.onDismiss - do not pass it along to children

			var classNames = (0, _classnames2.default)(className, 'modal');

			var modalClasses = (0, _classnames2.default)('view view--modal', {
				'view--modalFull': fullscreen,
				'view--modalFixed': fixed && !this.state.isMobileSize,
				'view--modalSnap': !fullscreen,
				'modal--isLoading component--isLoading': isLoading
			});

			var overlayClasses = (0, _classnames2.default)('overlayShim', {
				'overlayShim--fixed': fixed && !this.state.isMobileSize
			});

			var dismissButtonClasses = (0, _classnames2.default)(MODAL_CLOSE_BUTTON, 'button--reset');

			var heroStyles = {
				backgroundColor: heroBgColor || 'transparent'
			};

			var overlayShim = _react2.default.createElement(
				'div',
				{ className: overlayClasses, onClick: this.onDismiss },
				_react2.default.createElement('div', { className: 'inverted' })
			);

			var closeElement = closeArea && _react2.default.createElement(
				'div',
				{
					className: (0, _classnames2.default)((_cx = {}, _defineProperty(_cx, MODAL_CLOSE_AREA_STICKY, stickyCloseArea), _defineProperty(_cx, MODAL_CLOSE_AREA_STICKYTRANSP, stickyCloseArea && (Boolean(heroBgColor) || Boolean(heroBgImage))), _defineProperty(_cx, 'border--none', stickyCloseArea && (Boolean(heroBgColor) || Boolean(heroBgImage))), _cx), 'padding--all modal-closeButtonContainer')
				},
				_react2.default.createElement(
					_Button2.default,
					{
						onClick: this.onDismiss,
						reset: true,
						className: dismissButtonClasses,
						'aria-label': 'Close'
					},
					_react2.default.createElement(_Icon2.default, { shape: 'cross', size: 's' })
				)
			);

			return _react2.default.createElement(
				'div',
				_extends({
					role: 'dialog',
					tabIndex: '0',
					onKeyDown: this.onKeyDown,
					className: classNames
				}, other),
				_react2.default.createElement(
					_focusTrapReact2.default,
					{
						focusTrapOptions: {
							initialFocus: initialFocus,
							escapeDeactivates: false
						},
						active: focusTrapActive
					},
					overlayShim,
					_react2.default.createElement(
						'div',
						{
							className: modalClasses,
							style: {
								marginTop: this.state.topPosition,
								maxHeight: fixed ? 'calc(100% - ' + this.state.topPosition + ')' : 'auto'
							}
						},
						heroContent ? _react2.default.createElement(
							_Stripe2.default,
							{
								backgroundImage: heroBgImage,
								inverted: inverted,
								hideScrim: hideHeroScrim,
								style: heroStyles
							},
							closeElement,
							heroContent
						) : closeElement,
						children
					)
				)
			);
		}
	}]);

	return ModalComponent;
}(_react2.default.Component);

ModalComponent.propTypes = {
	/** Whether the modal should cover the entire screen */
	fullscreen: _propTypes2.default.bool,

	/** Whether the modal should scroll with the document */
	fixed: _propTypes2.default.bool,

	/** Background color for the modal's hero content area */
	heroBgColor: _propTypes2.default.string,

	/** Background image for the modal's hero content area */
	heroBgImage: _propTypes2.default.string,

	/** Content to render in the modal's hero content area */
	heroContent: _propTypes2.default.element,

	/** Whether to shade the modal's hero area with a text protection scrim */
	hideHeroScrim: _propTypes2.default.bool,

	/** Whether the modal's hero area is dark instead of light */
	inverted: _propTypes2.default.bool,

	/** Callback that happens when a user dismisses the modal */
	onDismiss: _propTypes2.default.func.isRequired,

	/** Whether to render the close button in the top corner of the modal */
	closeArea: _propTypes2.default.bool,

	/** Whether the close button should stick to the top of the modal when the modal is scrolled */
	stickyCloseArea: _propTypes2.default.bool,

	/** Which element inside the modal should get focus when the Modal mounts and renders */
	initialFocus: _propTypes2.default.oneOfType([_propTypes2.default.element, _propTypes2.default.func, _propTypes2.default.string]),

	/** Whether focus is trapped within the modal */
	focusTrapActive: _propTypes2.default.bool,

	/** Whether the component is in a loading state */
	isLoading: _propTypes2.default.bool,

	/** Props to pass to the `<Loading />` component */
	loadingProps: _propTypes2.default.shape({
		color: _propTypes2.default.string,
		scrimColor: _propTypes2.default.string,
		size: _propTypes2.default.string
	})
};

ModalComponent.defaultProps = {
	fullscreen: false,
	closeArea: true,
	focusTrapActive: true
};

var Modal = (0, _withLoading2.default)(ModalComponent);
Modal.displayName = 'Modal';
exports.default = Modal;
ModalComponent.__docgenInfo = {
	'description': 'SQ2 Modal component\n@see {@link http://meetup.github.io/sassquatch2/views.html#modals}\n@module ModalComponent',
	'methods': [{
		'name': 'onDismiss',
		'docblock': null,
		'modifiers': [],
		'params': [{
			'name': 'e',
			'type': null
		}],
		'returns': null
	}, {
		'name': 'onKeyDown',
		'docblock': null,
		'modifiers': [],
		'params': [{
			'name': 'e',
			'type': null
		}],
		'returns': null
	}],
	'displayName': 'ModalComponent',
	'props': {
		'fullscreen': {
			'defaultValue': {
				'value': 'false',
				'computed': false
			},
			'type': {
				'name': 'bool'
			},
			'required': false,
			'description': 'Whether the modal should cover the entire screen'
		},
		'closeArea': {
			'defaultValue': {
				'value': 'true',
				'computed': false
			},
			'type': {
				'name': 'bool'
			},
			'required': false,
			'description': 'Whether to render the close button in the top corner of the modal'
		},
		'focusTrapActive': {
			'defaultValue': {
				'value': 'true',
				'computed': false
			},
			'type': {
				'name': 'bool'
			},
			'required': false,
			'description': 'Whether focus is trapped within the modal'
		},
		'fixed': {
			'type': {
				'name': 'bool'
			},
			'required': false,
			'description': 'Whether the modal should scroll with the document'
		},
		'heroBgColor': {
			'type': {
				'name': 'string'
			},
			'required': false,
			'description': 'Background color for the modal\'s hero content area'
		},
		'heroBgImage': {
			'type': {
				'name': 'string'
			},
			'required': false,
			'description': 'Background image for the modal\'s hero content area'
		},
		'heroContent': {
			'type': {
				'name': 'element'
			},
			'required': false,
			'description': 'Content to render in the modal\'s hero content area'
		},
		'hideHeroScrim': {
			'type': {
				'name': 'bool'
			},
			'required': false,
			'description': 'Whether to shade the modal\'s hero area with a text protection scrim'
		},
		'inverted': {
			'type': {
				'name': 'bool'
			},
			'required': false,
			'description': 'Whether the modal\'s hero area is dark instead of light'
		},
		'onDismiss': {
			'type': {
				'name': 'func'
			},
			'required': true,
			'description': 'Callback that happens when a user dismisses the modal'
		},
		'stickyCloseArea': {
			'type': {
				'name': 'bool'
			},
			'required': false,
			'description': 'Whether the close button should stick to the top of the modal when the modal is scrolled'
		},
		'initialFocus': {
			'type': {
				'name': 'union',
				'value': [{
					'name': 'element'
				}, {
					'name': 'func'
				}, {
					'name': 'string'
				}]
			},
			'required': false,
			'description': 'Which element inside the modal should get focus when the Modal mounts and renders'
		},
		'isLoading': {
			'type': {
				'name': 'bool'
			},
			'required': false,
			'description': 'Whether the component is in a loading state'
		},
		'loadingProps': {
			'type': {
				'name': 'shape',
				'value': {
					'color': {
						'name': 'string',
						'required': false
					},
					'scrimColor': {
						'name': 'string',
						'required': false
					},
					'size': {
						'name': 'string',
						'required': false
					}
				}
			},
			'required': false,
			'description': 'Props to pass to the `<Loading />` component'
		}
	}
};
//# sourceMappingURL=Modal.js.map