'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _Card = require('./Card');

var _Card2 = _interopRequireDefault(_Card);

var _Bounds = require('./Bounds');

var _Bounds2 = _interopRequireDefault(_Bounds);

var _Section = require('./Section');

var _Section2 = _interopRequireDefault(_Section);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Wrapping component to standardize the structure of form sections.
 * @module FormSection
 * @param {object} props React props
 * @return {React.element} Form section wrapping component
 */

function FormSection(_ref) {
	var className = _ref.className,
	    children = _ref.children,
	    withSeparator = _ref.withSeparator,
	    _ref$loadingProps = _ref.loadingProps,
	    loadingProps = _ref$loadingProps === undefined ? {} : _ref$loadingProps,
	    isLoading = _ref.isLoading;

	return _react2.default.createElement(
		_Section2.default,
		{ hasSeparator: withSeparator, className: (0, _classnames2.default)(className, 'border--none') },
		_react2.default.createElement(
			_Card2.default,
			{
				initialHeight: true,
				flushUntil: 'large',
				isLoading: isLoading,
				loadingProps: loadingProps
			},
			_react2.default.createElement(
				_Bounds2.default,
				{ narrow: true },
				_react2.default.createElement(
					_Section2.default,
					{ hasSeparator: true, className: 'border--none padding--top' },
					children
				)
			)
		)
	);
}
exports.default = FormSection;
FormSection.__docgenInfo = {
	'description': '',
	'methods': [],
	'displayName': 'FormSection',
	'props': {
		'loadingProps': {
			'defaultValue': {
				'value': '{}',
				'computed': false
			},
			'flowType': {
				'name': 'signature',
				'type': 'object',
				'raw': '{\n    color?: string,\n    scrimColor?: string,\n    size?: MediaSizes,\n}',
				'signature': {
					'properties': [{
						'key': 'color',
						'value': {
							'name': 'string',
							'required': false
						}
					}, {
						'key': 'scrimColor',
						'value': {
							'name': 'string',
							'required': false
						}
					}, {
						'key': 'size',
						'value': {
							'name': 'MediaSizes',
							'required': false
						}
					}]
				}
			},
			'required': false,
			'description': 'Props to pass to the `<Loading />` component'
		},
		'withSeparator': {
			'flowType': {
				'name': 'boolean'
			},
			'required': false,
			'description': 'Whether the inner `<Section />` has a separator (extra spacing and a border on the bottom)'
		},
		'isLoading': {
			'flowType': {
				'name': 'boolean'
			},
			'required': false,
			'description': 'Whether the component is in a loading state'
		},
		'children': {
			'flowType': {
				'name': 'React$Node'
			},
			'required': true,
			'description': 'The child elements of the component'
		},
		'className': {
			'flowType': {
				'name': 'string'
			},
			'required': false,
			'description': 'Nearest DOM element\'s class name'
		}
	}
};
//# sourceMappingURL=FormSection.js.map