'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.getPhotoSize = exports.getPhoto = exports.AVATAR_PERSON_NOPHOTO_CLASS = exports.AVATAR_PERSON_FB_CLASS = exports.AVATAR_PERSON_ORG_CLASS = exports.AVATAR_PERSON_CLASS = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _Avatar = require('./Avatar');

var _Avatar2 = _interopRequireDefault(_Avatar);

var _Icon = require('./Icon');

var _Icon2 = _interopRequireDefault(_Icon);

var _organizerBadge = require('../../assets/svg/organizer-badge.svg');

var _organizerBadge2 = _interopRequireDefault(_organizerBadge);

var _memberPlusBadge = require('../../assets/svg/member-plus-badge.svg');

var _memberPlusBadge2 = _interopRequireDefault(_memberPlusBadge);

var _hostBadge = require('../../assets/svg/host-badge.svg');

var _hostBadge2 = _interopRequireDefault(_hostBadge);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var AVATAR_PERSON_CLASS = exports.AVATAR_PERSON_CLASS = 'avatar--person';
var AVATAR_PERSON_ORG_CLASS = exports.AVATAR_PERSON_ORG_CLASS = 'avatar--org';
var AVATAR_PERSON_FB_CLASS = exports.AVATAR_PERSON_FB_CLASS = 'avatar--fbFriend';
var AVATAR_PERSON_NOPHOTO_CLASS = exports.AVATAR_PERSON_NOPHOTO_CLASS = 'avatar--noPhoto';
var AVATAR_ICON_BADGE_CLASS = 'svg--avatarBadge';


var AVATAR_IMAGE_SIZE_LIST = ['big', 'default'];
var BADGES = {
	ORGANIZER: 'organizer',
	MEMBER_PLUS: 'memberPlus',
	HOST: 'host'
};

var getPhoto = exports.getPhoto = function getPhoto(photo, size) {
	if (!photo) {
		return undefined;
	}
	switch (size) {
		case 'big':
			return photo.photo_link || photo.highres_link; // use highres_link as a fallback
		default:
			return photo.thumb_link;
	}
};

// Use `imageSize` prop to control image resolution independently from component size
var getPhotoSize = exports.getPhotoSize = function getPhotoSize(imageSize, isBig) {
	if (imageSize) {
		return imageSize;
	}
	return isBig ? 'big' : 'default';
};

var getBadge = function getBadge(type) {
	switch (type) {
		case BADGES.ORGANIZER:
			return _react2.default.createElement('img', { className: AVATAR_ICON_BADGE_CLASS, src: _organizerBadge2.default });
		case BADGES.MEMBER_PLUS:
			return _react2.default.createElement('img', { className: AVATAR_ICON_BADGE_CLASS, src: _memberPlusBadge2.default });
		case BADGES.HOST:
			return _react2.default.createElement('img', { className: AVATAR_ICON_BADGE_CLASS, src: _hostBadge2.default });
		default:
			return null;
	}
};

/**
 * An avatar for a member - just supply a member
 * @module AvatarMember
 */

var AvatarMember = function (_React$PureComponent) {
	_inherits(AvatarMember, _React$PureComponent);

	function AvatarMember() {
		_classCallCheck(this, AvatarMember);

		return _possibleConstructorReturn(this, (AvatarMember.__proto__ || Object.getPrototypeOf(AvatarMember)).apply(this, arguments));
	}

	_createClass(AvatarMember, [{
		key: 'render',
		value: function render() {
			var _cx;

			var _props = this.props,
			    member = _props.member,
			    org = _props.org,
			    fbFriend = _props.fbFriend,
			    className = _props.className,
			    imageSize = _props.imageSize,
			    badgeType = _props.badgeType,
			    other = _objectWithoutProperties(_props, ['member', 'org', 'fbFriend', 'className', 'imageSize', 'badgeType']);

			var big = other.big,
			    large = other.large,
			    xxlarge = other.xxlarge;


			var photoSize = getPhotoSize(imageSize, big || large || xxlarge);
			var photoLink = getPhoto(member.photo, photoSize);
			var showNoPhoto = typeof photoLink !== 'string'; // _any_ non-string value should be considered invalid.

			var classNames = (0, _classnames2.default)(AVATAR_PERSON_CLASS, (_cx = {}, _defineProperty(_cx, AVATAR_PERSON_ORG_CLASS, org || badgeType), _defineProperty(_cx, AVATAR_PERSON_FB_CLASS, fbFriend), _defineProperty(_cx, AVATAR_PERSON_NOPHOTO_CLASS, showNoPhoto), _cx), className);

			var allProps = {
				alt: member.name,
				className: classNames
			};

			if (!showNoPhoto) {
				allProps.src = photoLink;
			}

			return _react2.default.createElement(
				_Avatar2.default,
				_extends({}, allProps, other),
				showNoPhoto && _react2.default.createElement(_Icon2.default, {
					className: 'avatarIcon--noPhoto display--inlineFlex',
					shape: 'profile',
					size: 'm'
				}),
				fbFriend && !org && _react2.default.createElement(_Icon2.default, {
					className: AVATAR_ICON_BADGE_CLASS,
					shape: 'external-facebook',
					size: 'm'
				}),
				org && _react2.default.createElement(_Icon2.default, { className: AVATAR_ICON_BADGE_CLASS, shape: 'badge', size: 'm' }),
				badgeType && getBadge(badgeType)
			);
		}
	}]);

	return AvatarMember;
}(_react2.default.PureComponent);

AvatarMember.propTypes = {
	/** Would like to deprecate this in favor of xxlarge */
	big: _propTypes2.default.bool,

	/** Render Avatar at a medium size */
	medium: _propTypes2.default.bool,

	/** Render Avatar at a larger size */
	large: _propTypes2.default.bool,

	/** Render Avatar at a very large size */
	xxlarge: _propTypes2.default.bool,

	/** Data for the person who's avatar we're displaying */
	member: _propTypes2.default.object.isRequired,

	/** Whether this avatar is for an organizer */
	org: _propTypes2.default.bool,

	/** Whether this avatar is for a person the user is friends with on FB */
	fbFriend: _propTypes2.default.bool,

	/** Image size */
	imageSize: _propTypes2.default.oneOf(AVATAR_IMAGE_SIZE_LIST),

	/** Badge type */
	badgeType: _propTypes2.default.oneOf(Object.values(BADGES))
};

AvatarMember.BADGES = BADGES;

exports.default = AvatarMember;
AvatarMember.__docgenInfo = {
	'description': 'An avatar for a member - just supply a member\n@module AvatarMember',
	'methods': [],
	'displayName': 'AvatarMember',
	'props': {
		'big': {
			'type': {
				'name': 'bool'
			},
			'required': false,
			'description': 'Would like to deprecate this in favor of xxlarge'
		},
		'medium': {
			'type': {
				'name': 'bool'
			},
			'required': false,
			'description': 'Render Avatar at a medium size'
		},
		'large': {
			'type': {
				'name': 'bool'
			},
			'required': false,
			'description': 'Render Avatar at a larger size'
		},
		'xxlarge': {
			'type': {
				'name': 'bool'
			},
			'required': false,
			'description': 'Render Avatar at a very large size'
		},
		'member': {
			'type': {
				'name': 'object'
			},
			'required': true,
			'description': 'Data for the person who\'s avatar we\'re displaying'
		},
		'org': {
			'type': {
				'name': 'bool'
			},
			'required': false,
			'description': 'Whether this avatar is for an organizer'
		},
		'fbFriend': {
			'type': {
				'name': 'bool'
			},
			'required': false,
			'description': 'Whether this avatar is for a person the user is friends with on FB'
		},
		'imageSize': {
			'type': {
				'name': 'enum',
				'value': [{
					'value': '\'big\'',
					'computed': false
				}, {
					'value': '\'default\'',
					'computed': false
				}]
			},
			'required': false,
			'description': 'Image size'
		},
		'badgeType': {
			'type': {
				'name': 'enum',
				'computed': true,
				'value': 'Object.values(BADGES)'
			},
			'required': false,
			'description': 'Badge type'
		}
	}
};
//# sourceMappingURL=AvatarMember.js.map