'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.LOADING_SHAPE_PATH_CLASS = exports.LOADING_SHAPE_CLASS = exports.LOADING_CLASS = undefined;

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _constants = require('swarm-constants/dist/js/constants');

var _designConstants = require('../utils/designConstants');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

// TODO: replace MEDIA_SIZES with size values
// from `swarm-constants` when available in JS


var LOADING_CLASS = exports.LOADING_CLASS = 'loading';
var LOADING_SHAPE_CLASS = exports.LOADING_SHAPE_CLASS = 'loadingShape';
var LOADING_SHAPE_PATH_CLASS = exports.LOADING_SHAPE_PATH_CLASS = LOADING_SHAPE_CLASS + '-path';

var Loading = function Loading(_ref) {
	var _cx;

	var className = _ref.className,
	    color = _ref.color,
	    scrimColor = _ref.scrimColor,
	    size = _ref.size,
	    fullCover = _ref.fullCover,
	    partialCover = _ref.partialCover,
	    other = _objectWithoutProperties(_ref, ['className', 'color', 'scrimColor', 'size', 'fullCover', 'partialCover']);

	var isCover = fullCover || partialCover;
	var classNames = (0, _classnames2.default)(LOADING_CLASS, (_cx = {}, _defineProperty(_cx, LOADING_CLASS + '--cover', isCover), _defineProperty(_cx, LOADING_CLASS + '--fullCover', fullCover), _defineProperty(_cx, LOADING_CLASS + '--partialCover', partialCover), _cx), className);

	return _react2.default.createElement(
		'div',
		{
			className: classNames,
			style: isCover && {
				backgroundColor: scrimColor
			}
		},
		_react2.default.createElement(
			'svg',
			{
				'aria-labelledby': 'title',
				role: 'progressbar',
				className: LOADING_SHAPE_CLASS,
				viewBox: '0 0 50 50',
				style: { width: size }
			},
			_react2.default.createElement(
				'title',
				{ id: 'title', className: 'visibility--a11yHide' },
				'Loading'
			),
			_react2.default.createElement('circle', {
				className: LOADING_SHAPE_PATH_CLASS,
				cx: '25',
				cy: '25',
				r: '20',
				fill: 'none',
				stroke: color,
				strokeWidth: '3',
				strokeMiterlimit: '10'
			})
		)
	);
};

Loading.defaultProps = {
	color: _constants.C_COOLGRAYMEDIUM,
	scrimColor: 'rgba(255,255,255, .87)',
	size: _designConstants.MEDIA_SIZES.l + 'px'
};

Loading.propTypes = {
	/** What color the spinning graphic should be filled with */
	color: _propTypes2.default.string,

	/** Whether to cover the entire screen with a loader */
	fullCover: _propTypes2.default.bool,

	/** Whether to cover the component's parent container */
	partialCover: _propTypes2.default.bool,

	/** The color of the overlay that covers content */
	scrimColor: _propTypes2.default.string,

	/** The width of the loading graphic */
	size: _propTypes2.default.string
};

exports.default = Loading;
Loading.__docgenInfo = {
	'description': '',
	'methods': [],
	'props': {
		'color': {
			'defaultValue': {
				'value': 'C_COOLGRAYMEDIUM',
				'computed': true
			},
			'type': {
				'name': 'string'
			},
			'required': false,
			'description': 'What color the spinning graphic should be filled with'
		},
		'scrimColor': {
			'defaultValue': {
				'value': '\'rgba(255,255,255, .87)\'',
				'computed': false
			},
			'type': {
				'name': 'string'
			},
			'required': false,
			'description': 'The color of the overlay that covers content'
		},
		'size': {
			'defaultValue': {
				'value': '`${MEDIA_SIZES.l}px`',
				'computed': false
			},
			'type': {
				'name': 'string'
			},
			'required': false,
			'description': 'The width of the loading graphic'
		},
		'fullCover': {
			'type': {
				'name': 'bool'
			},
			'required': false,
			'description': 'Whether to cover the entire screen with a loader'
		},
		'partialCover': {
			'type': {
				'name': 'bool'
			},
			'required': false,
			'description': 'Whether to cover the component\'s parent container'
		}
	}
};
//# sourceMappingURL=Loading.js.map