'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.NavItem = exports.DropdownItem = exports.LinkItem = exports.ActionItem = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _Button = require('../../forms/Button');

var _Button2 = _interopRequireDefault(_Button);

var _Dropdown = require('../../interactive/Dropdown');

var _Dropdown2 = _interopRequireDefault(_Dropdown);

var _FlexItem = require('../../layout/FlexItem');

var _FlexItem2 = _interopRequireDefault(_FlexItem);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

var NAV_ITEM_CLASS = 'navItemLink';

var ActionItem = exports.ActionItem = function ActionItem(_ref) {
	var navItemContent = _ref.navItemContent,
	    action = _ref.action,
	    attributes = _ref.attributes;
	return _react2.default.createElement(
		_Button2.default,
		_extends({
			reset: true,
			className: (0, _classnames2.default)(NAV_ITEM_CLASS, 'text--secondary', 'padding--none'),
			onClick: action
		}, attributes),
		navItemContent
	);
};
var LinkItem = exports.LinkItem = function LinkItem(_ref2) {
	var linkTo = _ref2.linkTo,
	    navItemContent = _ref2.navItemContent,
	    className = _ref2.className,
	    onLinkClick = _ref2.onLinkClick,
	    isTargetBlank = _ref2.isTargetBlank,
	    attributes = _ref2.attributes;
	return _react2.default.createElement(
		'a',
		_extends({
			href: linkTo,
			className: (0, _classnames2.default)(NAV_ITEM_CLASS, className),
			onClick: onLinkClick,
			target: isTargetBlank ? '_blank' : '',
			'aria-label': NAV_ITEM_CLASS,
			title: NAV_ITEM_CLASS
		}, attributes),
		navItemContent
	);
};
var DropdownItem = exports.DropdownItem = function DropdownItem(_ref3) {
	var navItemContent = _ref3.navItemContent,
	    dropdownContent = _ref3.dropdownContent,
	    isNewNavActive = _ref3.isNewNavActive;
	return _react2.default.createElement(_Dropdown2.default, {
		noPortal: true,
		align: 'right',
		maxWidth: '544px',
		minWidth: isNewNavActive ? '190px' : '384px',
		trigger: navItemContent,
		content: dropdownContent
	});
};

/**
 * NavItem
 *
 * Renders a dropdown if `dropdownContent` prop is passed,
 * otherwise relies on a `linkTo` prop to render a link item.
 *
 * @param {Object} props - React element props
 * @returns {React.element} - navigation segment of header
 */
var NavItem = function NavItem(props) {
	var linkTo = props.linkTo,
	    label = props.label,
	    shrink = props.shrink,
	    className = props.className,
	    labelClassName = props.labelClassName,
	    linkClassName = props.linkClassName,
	    counterBadgeClassName = props.counterBadgeClassName,
	    dropdownContent = props.dropdownContent,
	    icon = props.icon,
	    hasUpdates = props.hasUpdates,
	    onClickAction = props.onClickAction,
	    onAction = props.onAction,
	    updatesLabel = props.updatesLabel,
	    isNewNavActive = props.isNewNavActive,
	    onLinkClick = props.onLinkClick,
	    isTargetBlank = props.isTargetBlank,
	    actionAttributes = props.actionAttributes,
	    other = _objectWithoutProperties(props, ['linkTo', 'label', 'shrink', 'className', 'labelClassName', 'linkClassName', 'counterBadgeClassName', 'dropdownContent', 'icon', 'hasUpdates', 'onClickAction', 'onAction', 'updatesLabel', 'isNewNavActive', 'onLinkClick', 'isTargetBlank', 'actionAttributes']);

	var classNames = {
		navItem: (0, _classnames2.default)('navItem', className),
		label: (0, _classnames2.default)('navItem-label', labelClassName),
		counterBadge: counterBadgeClassName || 'counterBadge'
	};

	var navItemContent = _react2.default.createElement(
		'div',
		null,
		icon,
		label && _react2.default.createElement(
			'span',
			{ className: classNames.label },
			label
		),
		hasUpdates && _react2.default.createElement(
			'span',
			{ className: classNames.counterBadge },
			_react2.default.createElement(
				'span',
				{ className: 'visibility--a11yHide' },
				updatesLabel
			)
		)
	);

	var trigger = _react2.default.createElement(
		'div',
		_extends({
			role: 'button',
			'aria-haspopup': true,
			className: NAV_ITEM_CLASS,
			onClick: onClickAction
		}, actionAttributes),
		navItemContent
	);

	return _react2.default.createElement(
		_FlexItem2.default,
		_extends({ shrink: shrink, className: classNames.navItem }, other),
		linkTo && _react2.default.createElement(LinkItem, {
			className: linkClassName,
			linkTo: linkTo,
			navItemContent: navItemContent,
			onLinkClick: onLinkClick,
			isTargetBlank: isTargetBlank,
			attributes: actionAttributes
		}),
		dropdownContent && _react2.default.createElement(DropdownItem, {
			dropdownContent: dropdownContent,
			navItemContent: trigger,
			isNewNavActive: isNewNavActive
		}),
		onAction && _react2.default.createElement(ActionItem, {
			action: onAction,
			navItemContent: navItemContent,
			attributes: actionAttributes
		})
	);
};

exports.NavItem = NavItem;
NavItem.propTypes = {
	linkTo: _propTypes2.default.string,
	dropdownContent: _propTypes2.default.element,
	onClickAction: _propTypes2.default.func,
	onAction: _propTypes2.default.func,
	label: _propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.element]),
	shrink: _propTypes2.default.bool,
	className: _propTypes2.default.string,
	labelClassName: _propTypes2.default.string,
	linkClassName: _propTypes2.default.string,
	counterBadgeClassName: _propTypes2.default.string,
	icon: _propTypes2.default.element,
	hasUpdates: _propTypes2.default.bool,
	isNewNavActive: _propTypes2.default.bool,
	onLinkClick: _propTypes2.default.func,
	isTargetBlank: _propTypes2.default.bool,
	actionAttributes: _propTypes2.default.object
};

exports.default = NavItem;
ActionItem.__docgenInfo = {
	'description': '',
	'methods': []
};
LinkItem.__docgenInfo = {
	'description': '',
	'methods': []
};
DropdownItem.__docgenInfo = {
	'description': '',
	'methods': []
};
NavItem.__docgenInfo = {
	'description': 'NavItem\n\nRenders a dropdown if `dropdownContent` prop is passed,\notherwise relies on a `linkTo` prop to render a link item.\n\n@param {Object} props - React element props\n@returns {React.element} - navigation segment of header',
	'methods': [],
	'props': {
		'linkTo': {
			'type': {
				'name': 'string'
			},
			'required': false,
			'description': ''
		},
		'dropdownContent': {
			'type': {
				'name': 'element'
			},
			'required': false,
			'description': ''
		},
		'onClickAction': {
			'type': {
				'name': 'func'
			},
			'required': false,
			'description': ''
		},
		'onAction': {
			'type': {
				'name': 'func'
			},
			'required': false,
			'description': ''
		},
		'label': {
			'type': {
				'name': 'union',
				'value': [{
					'name': 'string'
				}, {
					'name': 'element'
				}]
			},
			'required': false,
			'description': ''
		},
		'shrink': {
			'type': {
				'name': 'bool'
			},
			'required': false,
			'description': ''
		},
		'className': {
			'type': {
				'name': 'string'
			},
			'required': false,
			'description': ''
		},
		'labelClassName': {
			'type': {
				'name': 'string'
			},
			'required': false,
			'description': ''
		},
		'linkClassName': {
			'type': {
				'name': 'string'
			},
			'required': false,
			'description': ''
		},
		'counterBadgeClassName': {
			'type': {
				'name': 'string'
			},
			'required': false,
			'description': ''
		},
		'icon': {
			'type': {
				'name': 'element'
			},
			'required': false,
			'description': ''
		},
		'hasUpdates': {
			'type': {
				'name': 'bool'
			},
			'required': false,
			'description': ''
		},
		'isNewNavActive': {
			'type': {
				'name': 'bool'
			},
			'required': false,
			'description': ''
		},
		'onLinkClick': {
			'type': {
				'name': 'func'
			},
			'required': false,
			'description': ''
		},
		'isTargetBlank': {
			'type': {
				'name': 'bool'
			},
			'required': false,
			'description': ''
		},
		'actionAttributes': {
			'type': {
				'name': 'object'
			},
			'required': false,
			'description': ''
		}
	}
};
//# sourceMappingURL=NavItem.js.map