'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.DashboardDropdownComponent = exports.PROFILE_GROUP_LIST_ITEM_CLASS = exports.PROFILE_CLASS = undefined;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _Flex = require('../../../layout/Flex');

var _Flex2 = _interopRequireDefault(_Flex);

var _FlexItem = require('../../../layout/FlexItem');

var _FlexItem2 = _interopRequireDefault(_FlexItem);

var _Modal = require('../../../interactive/Modal');

var _Modal2 = _interopRequireDefault(_Modal);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var PROFILE_CLASS = exports.PROFILE_CLASS = 'profileDropdown-content';
var PROFILE_GROUP_LIST_ITEM_CLASS = exports.PROFILE_GROUP_LIST_ITEM_CLASS = 'profileDropdown-content-group';

/**
 * Creates dashboard dropdown used in navbar mobile implementation,
 * contains links to Pro Admin pages.
 * @param  {Object} labels and links to useful pages
 * @return {React.element} composed component
 */
var DashboardDropdownComponent = exports.DashboardDropdownComponent = function DashboardDropdownComponent(_ref) {
	var mobileTabs = _ref.mobileTabs,
	    dismissAction = _ref.dismissAction;
	var help = mobileTabs.help,
	    profile = mobileTabs.profile,
	    logout = mobileTabs.logout,
	    analytics = mobileTabs.analytics,
	    groups = mobileTabs.groups,
	    events = mobileTabs.events,
	    templates = mobileTabs.templates,
	    publicProfile = mobileTabs.publicProfile,
	    contact = mobileTabs.contact;

	var _ref2 = mobileTabs || {},
	    members = _ref2.members;

	return _react2.default.createElement(
		_Modal2.default,
		{ onDismiss: dismissAction },
		_react2.default.createElement(
			_Flex2.default,
			{ justify: 'spaceBetween', className: 'align--left padding--all' },
			_react2.default.createElement(
				_FlexItem2.default,
				{ growFactor: 1, className: 'text--secondary margin--left' },
				_react2.default.createElement(
					'ul',
					{ className: 'list' },
					_react2.default.createElement(
						'li',
						{ className: 'list-item padding--bottom' },
						_react2.default.createElement(
							'a',
							{ href: analytics.link },
							analytics.label
						)
					),
					Boolean(members) && _react2.default.createElement(
						'li',
						{ className: 'list-item padding--bottom' },
						_react2.default.createElement(
							'a',
							{ href: members.link },
							members.label
						)
					),
					_react2.default.createElement(
						'li',
						{ className: 'list-item padding--bottom' },
						_react2.default.createElement(
							'a',
							{ href: groups.link },
							groups.label
						)
					),
					_react2.default.createElement(
						'li',
						{ className: 'list-item padding--bottom' },
						_react2.default.createElement(
							'a',
							{ href: events.link },
							events.label
						)
					),
					_react2.default.createElement(
						'li',
						{ className: 'list-item padding--bottom' },
						_react2.default.createElement(
							'a',
							{ href: templates.link },
							templates.label
						)
					),
					_react2.default.createElement(
						'li',
						{ className: 'list-item padding--bottom' },
						_react2.default.createElement(
							'a',
							{ href: publicProfile.link },
							publicProfile.label
						)
					),
					_react2.default.createElement(
						'li',
						{ className: 'list-item' },
						_react2.default.createElement(
							'a',
							{ href: profile.link },
							profile.label
						)
					),
					_react2.default.createElement(
						'li',
						{ className: 'padding--top' },
						_react2.default.createElement(
							'a',
							{ href: contact.link },
							contact.label
						)
					),
					_react2.default.createElement(
						'li',
						{ className: 'padding--top' },
						_react2.default.createElement(
							'a',
							{ href: help.link },
							help.label
						)
					),
					_react2.default.createElement(
						'li',
						{ className: 'padding--top' },
						_react2.default.createElement(
							'a',
							{ href: logout.link },
							logout.label
						)
					)
				)
			)
		)
	);
};

DashboardDropdownComponent.propTypes = {
	mobileTabs: _propTypes2.default.shape({
		analytics: _propTypes2.default.shape({
			link: _propTypes2.default.string.isRequired,
			label: _propTypes2.default.string.isRequired
		}),
		members: _propTypes2.default.shape({
			link: _propTypes2.default.string.isRequired,
			label: _propTypes2.default.string.isRequired
		}),
		groups: _propTypes2.default.shape({
			link: _propTypes2.default.string.isRequired,
			label: _propTypes2.default.string.isRequired
		}),
		events: _propTypes2.default.shape({
			link: _propTypes2.default.string.isRequired,
			label: _propTypes2.default.string.isRequired
		}),
		templates: _propTypes2.default.shape({
			link: _propTypes2.default.string.isRequired,
			label: _propTypes2.default.string.isRequired
		}),
		publicProfile: _propTypes2.default.shape({
			link: _propTypes2.default.string.isRequired,
			label: _propTypes2.default.string.isRequired
		}),
		profile: _propTypes2.default.shape({
			link: _propTypes2.default.string.isRequired,
			label: _propTypes2.default.string.isRequired
		}),
		contact: _propTypes2.default.shape({
			link: _propTypes2.default.string.isRequired,
			label: _propTypes2.default.string.isRequired
		}),
		help: _propTypes2.default.shape({
			link: _propTypes2.default.string.isRequired,
			label: _propTypes2.default.string.isRequired
		}),
		logout: _propTypes2.default.shape({
			link: _propTypes2.default.string.isRequired,
			label: _propTypes2.default.string.isRequired
		})
	}),
	dismissAction: _propTypes2.default.func
};

exports.default = DashboardDropdownComponent;
DashboardDropdownComponent.__docgenInfo = {
	'description': 'Creates dashboard dropdown used in navbar mobile implementation,\ncontains links to Pro Admin pages.\n@param  {Object} labels and links to useful pages\n@return {React.element} composed component',
	'methods': [],
	'props': {
		'mobileTabs': {
			'type': {
				'name': 'shape',
				'value': {
					'analytics': {
						'name': 'shape',
						'value': {
							'link': {
								'name': 'string',
								'required': true
							},
							'label': {
								'name': 'string',
								'required': true
							}
						},
						'required': false
					},
					'members': {
						'name': 'shape',
						'value': {
							'link': {
								'name': 'string',
								'required': true
							},
							'label': {
								'name': 'string',
								'required': true
							}
						},
						'required': false
					},
					'groups': {
						'name': 'shape',
						'value': {
							'link': {
								'name': 'string',
								'required': true
							},
							'label': {
								'name': 'string',
								'required': true
							}
						},
						'required': false
					},
					'events': {
						'name': 'shape',
						'value': {
							'link': {
								'name': 'string',
								'required': true
							},
							'label': {
								'name': 'string',
								'required': true
							}
						},
						'required': false
					},
					'templates': {
						'name': 'shape',
						'value': {
							'link': {
								'name': 'string',
								'required': true
							},
							'label': {
								'name': 'string',
								'required': true
							}
						},
						'required': false
					},
					'publicProfile': {
						'name': 'shape',
						'value': {
							'link': {
								'name': 'string',
								'required': true
							},
							'label': {
								'name': 'string',
								'required': true
							}
						},
						'required': false
					},
					'profile': {
						'name': 'shape',
						'value': {
							'link': {
								'name': 'string',
								'required': true
							},
							'label': {
								'name': 'string',
								'required': true
							}
						},
						'required': false
					},
					'contact': {
						'name': 'shape',
						'value': {
							'link': {
								'name': 'string',
								'required': true
							},
							'label': {
								'name': 'string',
								'required': true
							}
						},
						'required': false
					},
					'help': {
						'name': 'shape',
						'value': {
							'link': {
								'name': 'string',
								'required': true
							},
							'label': {
								'name': 'string',
								'required': true
							}
						},
						'required': false
					},
					'logout': {
						'name': 'shape',
						'value': {
							'link': {
								'name': 'string',
								'required': true
							},
							'label': {
								'name': 'string',
								'required': true
							}
						},
						'required': false
					}
				}
			},
			'required': false,
			'description': ''
		},
		'dismissAction': {
			'type': {
				'name': 'func'
			},
			'required': false,
			'description': ''
		}
	}
};
//# sourceMappingURL=DashboardDropdown.js.map