'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.getIconShape = undefined;

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _Flex = require('../../../layout/Flex');

var _Flex2 = _interopRequireDefault(_Flex);

var _FlexItem = require('../../../layout/FlexItem');

var _FlexItem2 = _interopRequireDefault(_FlexItem);

var _Avatar = require('../../../media/Avatar');

var _Avatar2 = _interopRequireDefault(_Avatar);

var _Icon = require('../../../media/Icon');

var _Icon2 = _interopRequireDefault(_Icon);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var MEMBER_NOTIF_TYPES = ['mug_comm', 'convo', 'comment'];

/**
 * gets icon shape based on the "kind" of notification
 *
 * @param {String} notifKind - `kind` field of notification
 * @returns {String} - icon shape for notification
 */
var getIconShape = exports.getIconShape = function getIconShape(notifKind) {
	var shape = 'meetup-m';

	var notifKindToShape = {
		convo: 'messages',
		mug_comm: 'messages',
		comment: 'messages',
		event: 'calendar',
		dues: 'creditcard',
		like: 'heart'
	};

	Object.keys(notifKindToShape).forEach(function (kind) {
		if (notifKind.startsWith(kind)) {
			shape = notifKindToShape[kind];
		}
	});

	return shape;
};

/**
 * @module Notification
 */

var Notification = function (_React$PureComponent) {
	_inherits(Notification, _React$PureComponent);

	/**
  * @constructor
  * @param {Object} props passed in from parent
  */
	function Notification(props) {
		_classCallCheck(this, Notification);

		var _this = _possibleConstructorReturn(this, (Notification.__proto__ || Object.getPrototypeOf(Notification)).call(this, props));

		_this.state = {
			isRead: props.isRead
		};

		_this.onClick = _this.onClick.bind(_this);
		return _this;
	}

	/**
  * Marks notification read in internal state,
  * calls fn to make POST to 'notifications/read' endpoint
  *
  * @return {undefined}
  */


	_createClass(Notification, [{
		key: 'onClick',
		value: function onClick() {
			var _props = this.props,
			    id = _props.id,
			    isRead = _props.isRead,
			    onMarkReadAction = _props.onMarkReadAction;


			if (!isRead) {
				this.setState(function () {
					return { isRead: true };
				});
				onMarkReadAction(id);
			}
		}

		/**
   * @return {React.element} rendered single notification
   */

	}, {
		key: 'render',
		value: function render() {
			var _props2 = this.props,
			    memberId = _props2.memberId,
			    kind = _props2.kind,
			    formattedTimeSince = _props2.formattedTimeSince,
			    photoUrl = _props2.photoUrl,
			    link = _props2.link,
			    dangerouslySetInnerHTML = _props2.dangerouslySetInnerHTML,
			    className = _props2.className,
			    localeCode = _props2.localeCode,
			    generateClassicUrl = _props2.generateClassicUrl;


			var isMemberRelated = MEMBER_NOTIF_TYPES.some(function (t) {
				return kind.startsWith(t);
			});

			var classNames = (0, _classnames2.default)('list-item', 'notification', { 'notification--read': this.state.isRead }, className);

			var avatarClassNames = (0, _classnames2.default)('notification-image', {
				'avatar--person': isMemberRelated
			});

			var notifUrlWithTracking = generateClassicUrl(localeCode, '/r/site/' + kind + '/' + memberId + '/notification/' + link);

			return _react2.default.createElement(
				'a',
				{ href: notifUrlWithTracking, className: classNames, onClick: this.onClick },
				_react2.default.createElement(
					_Flex2.default,
					null,
					photoUrl && _react2.default.createElement(
						_FlexItem2.default,
						{ shrink: true, className: 'valignChildren--center' },
						_react2.default.createElement(_Avatar2.default, { className: avatarClassNames, src: photoUrl })
					),
					_react2.default.createElement(
						_FlexItem2.default,
						{ className: 'valignChildren--center' },
						_react2.default.createElement('h4', {
							className: 'text--small',
							dangerouslySetInnerHTML: dangerouslySetInnerHTML
						}),
						_react2.default.createElement(
							'p',
							{ className: 'text--hint text--small' },
							_react2.default.createElement(_Icon2.default, { shape: getIconShape(kind), size: 'xs' }),
							_react2.default.createElement(
								'time',
								{ className: 'notification-time text--small' },
								formattedTimeSince
							)
						)
					)
				)
			);
		}
	}]);

	return Notification;
}(_react2.default.PureComponent);

Notification.propTypes = {
	id: _propTypes2.default.string,
	memberId: _propTypes2.default.string,
	kind: _propTypes2.default.string,
	isRead: _propTypes2.default.bool,
	onMarkReadAction: _propTypes2.default.func.isRequired,
	link: _propTypes2.default.string,
	dangerouslySetInnerHTML: _propTypes2.default.shape({
		__html: _propTypes2.default.string
	}),
	photoUrl: _propTypes2.default.string,
	formattedTimeSince: _propTypes2.default.string,
	localeCode: _propTypes2.default.string.isRequired,
	className: _propTypes2.default.string,
	notifUrlWithTracking: _propTypes2.default.string,
	generateClassicUrl: _propTypes2.default.func.isRequired
};

exports.default = Notification;
//# sourceMappingURL=Notifications.js.map