'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.ProfileDropdownComponent = exports.PROFILE_GROUP_LIST_ITEM_CLASS = exports.PROFILE_CLASS = undefined;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _Button = require('../../../forms/Button');

var _Button2 = _interopRequireDefault(_Button);

var _Chunk = require('../../../layout/Chunk');

var _Chunk2 = _interopRequireDefault(_Chunk);

var _Flex = require('../../../layout/Flex');

var _Flex2 = _interopRequireDefault(_Flex);

var _FlexItem = require('../../../layout/FlexItem');

var _FlexItem2 = _interopRequireDefault(_FlexItem);

var _Icon = require('../../../media/Icon');

var _Icon2 = _interopRequireDefault(_Icon);

var _GroupDraftItem = require('../groupDraftItem/GroupDraftItem');

var _GroupDraftItem2 = _interopRequireDefault(_GroupDraftItem);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var PROFILE_CLASS = exports.PROFILE_CLASS = 'profileDropdown-content';
var PROFILE_GROUP_LIST_ITEM_CLASS = exports.PROFILE_GROUP_LIST_ITEM_CLASS = 'profileDropdown-content-group';

/**
 * Creates profile dropdown used in navbar have,
 * contains members groups + key links for user profile
 * @param  {Array} options.groups list of groups user is member of
 * @return {React.element} composed component
 */
var ProfileDropdownComponent = exports.ProfileDropdownComponent = function ProfileDropdownComponent(_ref) {
	var payments = _ref.payments,
	    settings = _ref.settings,
	    help = _ref.help,
	    profile = _ref.profile,
	    logout = _ref.logout,
	    groups = _ref.groups,
	    groupDraft = _ref.groupDraft,
	    groupHome = _ref.groupHome,
	    allGroupsLabel = _ref.allGroupsLabel,
	    allGroupsLink = _ref.allGroupsLink,
	    savedEvents = _ref.savedEvents,
	    yourEvents = _ref.yourEvents,
	    yourGroups = _ref.yourGroups,
	    isNewNavActive = _ref.isNewNavActive,
	    isNewNavsOrder = _ref.isNewNavsOrder,
	    yourConnections = _ref.yourConnections,
	    hasNewConnections = _ref.hasNewConnections;

	var groupsContent = groups.map(function (group) {
		return _react2.default.createElement(
			'li',
			{
				key: group.urlname,
				className: (0, _classnames2.default)(PROFILE_GROUP_LIST_ITEM_CLASS, 'list-item')
			},
			_react2.default.createElement(
				'a',
				{ href: groupHome(group.urlname) },
				group.name
			)
		);
	});

	var showGroups = Boolean(groups && groups.length || groupDraft);

	var oldNav = _react2.default.createElement(
		_FlexItem2.default,
		{
			growFactor: 1,
			className: (0, _classnames2.default)('text--secondary', { 'margin--left': showGroups })
		},
		_react2.default.createElement(
			'ul',
			{ className: 'list' },
			_react2.default.createElement(
				'li',
				{ className: 'list-item' },
				_react2.default.createElement(
					'a',
					{ href: profile.link },
					profile.label
				)
			),
			_react2.default.createElement(
				'li',
				{ className: 'list-item' },
				_react2.default.createElement(
					'a',
					{ href: payments.link },
					payments.label
				)
			),
			_react2.default.createElement(
				'li',
				{ className: 'list-item' },
				_react2.default.createElement(
					'a',
					{ href: settings.link },
					settings.label
				)
			),
			_react2.default.createElement(
				'li',
				{ className: 'list-item' },
				_react2.default.createElement(
					'a',
					{ href: help.link },
					help.label
				)
			),
			_react2.default.createElement(
				'li',
				{ className: 'list-item' },
				_react2.default.createElement(
					'a',
					{ href: logout.link },
					logout.label
				)
			)
		)
	);

	var newNav = isNewNavActive && _react2.default.createElement(
		_FlexItem2.default,
		{ growFactor: 1, className: (0, _classnames2.default)({ 'margin--left': showGroups }) },
		_react2.default.createElement(
			'ul',
			null,
			isNewNavsOrder ? _react2.default.createElement(
				_react.Fragment,
				null,
				_react2.default.createElement(
					'li',
					null,
					_react2.default.createElement(
						'a',
						{ className: 'links-item', href: yourEvents.link },
						yourEvents.label
					)
				),
				_react2.default.createElement(
					'li',
					null,
					_react2.default.createElement(
						'a',
						{ className: 'links-item', href: yourGroups.link },
						yourGroups.label
					)
				),
				!!yourConnections && _react2.default.createElement(
					'li',
					null,
					_react2.default.createElement(
						'a',
						{
							className: 'links-item links-item--connections',
							href: yourConnections.link
						},
						yourConnections.label,
						' ',
						hasNewConnections ? _react2.default.createElement('span', { className: 'navItem--counterBadgeConnections' }) : '🆕'
					)
				)
			) : _react2.default.createElement(
				_react.Fragment,
				null,
				_react2.default.createElement(
					'li',
					null,
					_react2.default.createElement(
						'a',
						{ className: 'links-item', href: savedEvents.link },
						savedEvents.label
					)
				),
				_react2.default.createElement(
					'li',
					null,
					_react2.default.createElement(
						'a',
						{ className: 'links-item', href: yourGroups.link },
						yourGroups.label
					)
				),
				_react2.default.createElement(
					'li',
					null,
					_react2.default.createElement(
						'a',
						{ className: 'links-item', href: yourEvents.link },
						yourEvents.label
					)
				)
			)
		),
		_react2.default.createElement('hr', { className: 'links-divider' }),
		_react2.default.createElement(
			'ul',
			null,
			_react2.default.createElement(
				'li',
				null,
				_react2.default.createElement(
					'a',
					{ className: 'links-item', href: profile.link },
					profile.label
				)
			),
			_react2.default.createElement(
				'li',
				null,
				_react2.default.createElement(
					'a',
					{ className: 'links-item', href: settings.link },
					settings.label
				)
			),
			_react2.default.createElement(
				'li',
				null,
				_react2.default.createElement(
					'a',
					{ className: 'links-item', href: help.link },
					help.label
				)
			),
			_react2.default.createElement(
				'li',
				null,
				_react2.default.createElement(
					'a',
					{ className: 'links-item', href: logout.link },
					logout.label
				)
			)
		)
	);

	return _react2.default.createElement(
		_Flex2.default,
		{
			justify: 'spaceBetween',
			className: (0, _classnames2.default)(PROFILE_CLASS, 'align--left', {
				'padding--all': !isNewNavActive,
				wide: !isNewNavActive || showGroups,
				'new-padding': isNewNavActive
			})
		},
		showGroups && _react2.default.createElement(
			_FlexItem2.default,
			{ growFactor: 2 },
			_react2.default.createElement(
				_Chunk2.default,
				null,
				_react2.default.createElement(
					'ul',
					{ className: 'list' },
					groupDraft && _react2.default.createElement(_GroupDraftItem2.default, { groupDraft: groupDraft }),
					groupsContent
				)
			),
			_react2.default.createElement(
				_Button2.default,
				{ small: true, href: allGroupsLink, component: 'a' },
				allGroupsLabel,
				_react2.default.createElement(_Icon2.default, { className: 'margin--left', shape: 'chevron-right', size: 'xs' })
			)
		),
		isNewNavActive ? newNav : oldNav
	);
};

ProfileDropdownComponent.propTypes = {
	profile: _propTypes2.default.shape({
		link: _propTypes2.default.string.isRequired,
		label: _propTypes2.default.string.isRequired
	}),
	payments: _propTypes2.default.shape({
		link: _propTypes2.default.string.isRequired,
		label: _propTypes2.default.string.isRequired
	}),
	settings: _propTypes2.default.shape({
		link: _propTypes2.default.string.isRequired,
		label: _propTypes2.default.string.isRequired
	}),
	help: _propTypes2.default.shape({
		link: _propTypes2.default.string.isRequired,
		label: _propTypes2.default.string.isRequired
	}),
	logout: _propTypes2.default.shape({
		link: _propTypes2.default.string.isRequired,
		label: _propTypes2.default.string.isRequired
	}),
	savedEvents: _propTypes2.default.shape({
		link: _propTypes2.default.string,
		label: _propTypes2.default.string
	}),
	yourGroups: _propTypes2.default.shape({
		link: _propTypes2.default.string,
		label: _propTypes2.default.string
	}),
	yourEvents: _propTypes2.default.shape({
		link: _propTypes2.default.string,
		label: _propTypes2.default.string
	}),
	groups: _propTypes2.default.arrayOf(_propTypes2.default.object),
	groupHome: _propTypes2.default.func.isRequired,
	allGroupsLabel: _propTypes2.default.string.isRequired,
	allGroupsLink: _propTypes2.default.string.isRequired,
	isNewNavActive: _propTypes2.default.bool
};

exports.default = ProfileDropdownComponent;
ProfileDropdownComponent.__docgenInfo = {
	'description': 'Creates profile dropdown used in navbar have,\ncontains members groups + key links for user profile\n@param  {Array} options.groups list of groups user is member of\n@return {React.element} composed component',
	'methods': [],
	'props': {
		'profile': {
			'type': {
				'name': 'shape',
				'value': {
					'link': {
						'name': 'string',
						'required': true
					},
					'label': {
						'name': 'string',
						'required': true
					}
				}
			},
			'required': false,
			'description': ''
		},
		'payments': {
			'type': {
				'name': 'shape',
				'value': {
					'link': {
						'name': 'string',
						'required': true
					},
					'label': {
						'name': 'string',
						'required': true
					}
				}
			},
			'required': false,
			'description': ''
		},
		'settings': {
			'type': {
				'name': 'shape',
				'value': {
					'link': {
						'name': 'string',
						'required': true
					},
					'label': {
						'name': 'string',
						'required': true
					}
				}
			},
			'required': false,
			'description': ''
		},
		'help': {
			'type': {
				'name': 'shape',
				'value': {
					'link': {
						'name': 'string',
						'required': true
					},
					'label': {
						'name': 'string',
						'required': true
					}
				}
			},
			'required': false,
			'description': ''
		},
		'logout': {
			'type': {
				'name': 'shape',
				'value': {
					'link': {
						'name': 'string',
						'required': true
					},
					'label': {
						'name': 'string',
						'required': true
					}
				}
			},
			'required': false,
			'description': ''
		},
		'savedEvents': {
			'type': {
				'name': 'shape',
				'value': {
					'link': {
						'name': 'string',
						'required': false
					},
					'label': {
						'name': 'string',
						'required': false
					}
				}
			},
			'required': false,
			'description': ''
		},
		'yourGroups': {
			'type': {
				'name': 'shape',
				'value': {
					'link': {
						'name': 'string',
						'required': false
					},
					'label': {
						'name': 'string',
						'required': false
					}
				}
			},
			'required': false,
			'description': ''
		},
		'yourEvents': {
			'type': {
				'name': 'shape',
				'value': {
					'link': {
						'name': 'string',
						'required': false
					},
					'label': {
						'name': 'string',
						'required': false
					}
				}
			},
			'required': false,
			'description': ''
		},
		'groups': {
			'type': {
				'name': 'arrayOf',
				'value': {
					'name': 'object'
				}
			},
			'required': false,
			'description': ''
		},
		'groupHome': {
			'type': {
				'name': 'func'
			},
			'required': true,
			'description': ''
		},
		'allGroupsLabel': {
			'type': {
				'name': 'string'
			},
			'required': true,
			'description': ''
		},
		'allGroupsLink': {
			'type': {
				'name': 'string'
			},
			'required': true,
			'description': ''
		},
		'isNewNavActive': {
			'type': {
				'name': 'bool'
			},
			'required': false,
			'description': ''
		}
	}
};
//# sourceMappingURL=ProfileDropdown.js.map