"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
/**
 * @function bindAll
 * helper for binding prototype methods to class context
 *
 * for example, instead of doing this in a class `constructor`:
 * `this.handleClick = this.handleClick.bind(this)`
 *
 * you can use `bindAll`:
 * ```
 * bindAll(this,
 * 	handleClick,
 * 	someOtherMethod,
 * 	anotherMethod);
 * ```
 */
var bindAll = function bindAll(context) {
  for (var _len = arguments.length, names = Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
    names[_key - 1] = arguments[_key];
  }

  names.forEach(function (name) {
    return context[name] = context[name].bind(context);
  });
};
exports.default = bindAll;
//# sourceMappingURL=bindAll.js.map