'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.calculateContentPosition = exports.getAdjustedAlignment = exports.calcLeftAlignment = exports.calcRightAlignment = exports.calcCenterAlignment = exports.ARROW_WIDTH = undefined;

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactPortal = require('react-portal');

var _rafSchd = require('raf-schd');

var _rafSchd2 = _interopRequireDefault(_rafSchd);

var _ConditionalWrap = require('./ConditionalWrap');

var _ConditionalWrap2 = _interopRequireDefault(_ConditionalWrap);

var _withMatchMedia = require('./withMatchMedia');

var _withMatchMedia2 = _interopRequireDefault(_withMatchMedia);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var ARROW_WIDTH = exports.ARROW_WIDTH = 19.5;

var calcCenterAlignment = exports.calcCenterAlignment = function calcCenterAlignment(distanceFromLeftEdge, width, scrollLeft, offsetLeft) {
	return distanceFromLeftEdge + width / 2 + scrollLeft + offsetLeft + 'px';
};
var calcRightAlignment = exports.calcRightAlignment = function calcRightAlignment(distanceFromLeftEdge, width, arrowWidth, scrollLeft, offsetLeft) {
	return distanceFromLeftEdge + arrowWidth + width / 2 + scrollLeft + offsetLeft + 'px';
};
var calcLeftAlignment = exports.calcLeftAlignment = function calcLeftAlignment(distanceFromLeftEdge, width, arrowWidth, scrollLeft, offsetLeft) {
	return distanceFromLeftEdge - arrowWidth + width / 2 + scrollLeft + offsetLeft + 'px';
};

var getAdjustedAlignment = exports.getAdjustedAlignment = function getAdjustedAlignment(preferredAlignment, triggerPositionData, contentWidth, viewportWidth) {
	var left = triggerPositionData.left,
	    width = triggerPositionData.width;

	var overflowLeft = left + width - contentWidth < 0;
	var overflowRight = left + contentWidth > viewportWidth;

	// if overflows viewport on the right side, right align the content
	if (overflowRight && !overflowLeft) {
		return 'right';
		// if overflows viewport on the left side, left align the content
	} else if (overflowLeft && !overflowRight) {
		return 'left';
		// but if there's no overflow OR there's overflow on
		// both sides, just use whatever alignment was passed
	} else {
		return preferredAlignment;
	}
};

var calculateContentPosition = exports.calculateContentPosition = function calculateContentPosition(_ref) {
	var trigger = _ref.trigger,
	    content = _ref.content,
	    addPortal = _ref.addPortal,
	    direction = _ref.direction,
	    _ref$offset = _ref.offset,
	    offset = _ref$offset === undefined ? {} : _ref$offset,
	    _ref$align = _ref.align,
	    align = _ref$align === undefined ? 'right' : _ref$align,
	    _ref$scrollLeft = _ref.scrollLeft,
	    scrollLeft = _ref$scrollLeft === undefined ? 0 : _ref$scrollLeft,
	    _ref$scrollTop = _ref.scrollTop,
	    scrollTop = _ref$scrollTop === undefined ? 0 : _ref$scrollTop;

	if (trigger && content) {
		var positionTarget = trigger().offsetParent ? trigger().offsetParent : trigger();
		var positionData = positionTarget.getBoundingClientRect();
		var leftPosition = positionData.left,
		    top = positionData.top,
		    width = positionData.width,
		    height = positionData.height;

		var offsetLeft = offset.left || 0;
		var offsetTop = offset.top || 0;
		var contentHeight = content().getBoundingClientRect().height;
		var contentWidth = content().getBoundingClientRect().width;
		var alignment = getAdjustedAlignment(align, positionData, contentWidth, window.innerWidth);
		if (addPortal === false) {
			if (direction === 'top') {
				return { top: contentHeight * -1, calculatedAlignment: alignment };
			} else {
				var targetElementHeight = positionTarget.getBoundingClientRect().height;
				return {
					top: targetElementHeight + offsetTop,
					calculatedAlignment: alignment
				};
			}
		} else {
			var left = 0;
			var triggerTopPosition = scrollTop + top + height + offsetTop;
			switch (alignment) {
				case 'center':
					left = calcCenterAlignment(leftPosition, width, scrollLeft, offsetLeft);
					break;

				case 'left':
					left = calcLeftAlignment(leftPosition, width, ARROW_WIDTH, scrollLeft, offsetLeft);
					break;
				case 'right':
				default:
					left = calcRightAlignment(leftPosition, width, ARROW_WIDTH, scrollLeft, offsetLeft);
					break;
			}
			var topPosition = direction === 'top' ? triggerTopPosition - contentHeight - height : triggerTopPosition;
			return { left: left, top: topPosition, calculatedAlignment: alignment };
		}
	}
};
/**
 * @module FloatingPosition
 */

var FloatingPosition = function (_React$PureComponent) {
	_inherits(FloatingPosition, _React$PureComponent);

	function FloatingPosition(props) {
		_classCallCheck(this, FloatingPosition);

		var _this = _possibleConstructorReturn(this, (FloatingPosition.__proto__ || Object.getPrototypeOf(FloatingPosition)).call(this, props));

		_this.getContentPosition = _this.getContentPosition.bind(_this);
		_this.scheduleUpdate = (0, _rafSchd2.default)(_this.getContentPosition);

		_this.state = {
			left: '0px',
			top: '0px',
			align: _this.props.align
		};
		return _this;
	}

	_createClass(FloatingPosition, [{
		key: 'getContentPosition',
		value: function getContentPosition() {
			var _props = this.props,
			    getTrigger = _props.getTrigger,
			    getContent = _props.getContent,
			    noPortal = _props.noPortal,
			    direction = _props.direction,
			    offset = _props.offset,
			    align = _props.align;


			var scrollTop = window.scrollY || window.pageYOffset;
			var scrollLeft = window.scrollX || window.pageXOffset;

			var _calculateContentPosi = calculateContentPosition({
				trigger: getTrigger,
				content: getContent,
				addPortal: !noPortal,
				direction: direction,
				offset: offset,
				align: align,
				scrollLeft: scrollLeft,
				scrollTop: scrollTop
			}),
			    left = _calculateContentPosi.left,
			    top = _calculateContentPosi.top,
			    calculatedAlignment = _calculateContentPosi.calculatedAlignment;

			this.setState(function () {
				return {
					left: left,
					top: top,
					align: calculatedAlignment
				};
			});
		}
	}, {
		key: 'componentDidMount',
		value: function componentDidMount() {
			this.scheduleUpdate();
			window.addEventListener('resize', this.scheduleUpdate);
			document.addEventListener('scroll', this.scheduleUpdate, true);
			this.props.handleClose && document.addEventListener('keydown', this.props.handleClose);
		}
	}, {
		key: 'componentWillUnmount',
		value: function componentWillUnmount() {
			this.scheduleUpdate.cancel();
			window.removeEventListener('resize', this.scheduleUpdate);
			document.removeEventListener('scroll', this.scheduleUpdate, true);
			this.props.handleClose && document.addEventListener('keydown', this.props.handleClose);
		}
	}, {
		key: 'render',
		value: function render() {
			var _this2 = this;

			var boundedMaxWidth = this.props.media.isAtSmallUp ? '350px' : '200px';

			return _react2.default.createElement(
				_ConditionalWrap2.default,
				{
					condition: !this.props.noPortal,
					wrap: function wrap(children) {
						return _this2.props.noPortal ? _react2.default.createElement(
							'div',
							null,
							children
						) : _react2.default.createElement(
							_reactPortal.Portal,
							null,
							children
						);
					}
				},
				this.props.children({
					left: this.state.left,
					top: this.state.top,
					align: this.state.align,
					boundedMaxWidth: boundedMaxWidth
				})
			);
		}
	}]);

	return FloatingPosition;
}(_react2.default.PureComponent);

FloatingPosition.defaultProps = {
	align: 'right'
};


FloatingPosition.propTypes = {
	getTrigger: _propTypes2.default.func.isRequired,
	getContent: _propTypes2.default.func.isRequired
};

exports.default = (0, _withMatchMedia2.default)(FloatingPosition);
FloatingPosition.__docgenInfo = {
	'description': '@module FloatingPosition',
	'methods': [{
		'name': 'getContentPosition',
		'docblock': null,
		'modifiers': [],
		'params': [],
		'returns': null
	}],
	'displayName': 'FloatingPosition',
	'props': {
		'align': {
			'defaultValue': {
				'value': '\'right\'',
				'computed': false
			}
		},
		'getTrigger': {
			'type': {
				'name': 'func'
			},
			'required': true,
			'description': ''
		},
		'getContent': {
			'type': {
				'name': 'func'
			},
			'required': true,
			'description': ''
		}
	}
};
//# sourceMappingURL=FloatingPosition.js.map