'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.getErrorId = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _ErrorList = require('../../forms/ErrorList');

var _ErrorList2 = _interopRequireDefault(_ErrorList);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/**
 * @function getErrorId
 * returns an id with which we can set ARIA
 * relationships between errors and form fields
 *
 * @param {string} id - the id of the form field
 * @returns {string} id for error list
 */
var getErrorId = exports.getErrorId = function getErrorId(id) {
	return id + '-error';
};

/**
 * Provides `ErrorList` component and aria related props
 * to wrapped form component
 *
 * @param {React.element} WrappedComponent - the component to wrap
 */
var withErrorList = function withErrorList(WrappedComponent) {
	/**
  * @module WithErrorList
  * Adds props to the wrapped form component for a11y.
  * Adds `ErrorList` as adjacent sibling to wrapped form.
  *
  * @returns {React.element}
  */
	var WithErrorList = function (_React$PureComponent) {
		_inherits(WithErrorList, _React$PureComponent);

		function WithErrorList() {
			_classCallCheck(this, WithErrorList);

			return _possibleConstructorReturn(this, (WithErrorList.__proto__ || Object.getPrototypeOf(WithErrorList)).apply(this, arguments));
		}

		_createClass(WithErrorList, [{
			key: 'render',
			value: function render() {
				var _props = this.props,
				    id = _props.id,
				    error = _props.error,
				    suppressError = _props.suppressError,
				    other = _objectWithoutProperties(_props, ['id', 'error', 'suppressError']);

				var errorId = id && getErrorId(id);

				return suppressError ? _react2.default.createElement(WrappedComponent, other) : _react2.default.createElement(
					'div',
					null,
					_react2.default.createElement(WrappedComponent, _extends({
						id: id,
						error: error,
						'aria-describedby': errorId,
						'aria-invalid': Boolean(error)
					}, other)),
					_react2.default.createElement(_ErrorList2.default, { id: errorId, error: error })
				);
			}
		}]);

		return WithErrorList;
	}(_react2.default.PureComponent);

	WithErrorList.propTypes = {
		id: _propTypes2.default.string,
		error: _propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.element, _propTypes2.default.bool]),
		suppressError: _propTypes2.default.bool
	};

	var wrappedComponentName = WrappedComponent.displayName || WrappedComponent.name || 'Component';

	WithErrorList.WrappedComponent = WrappedComponent;
	WithErrorList.displayName = 'WithErrorList(' + wrappedComponentName + ')';

	return WithErrorList;
};

exports.default = withErrorList;
//# sourceMappingURL=withErrorList.js.map