'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.getUpdatedMediaState = exports.getStateNameByBreakpoint = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _designConstants = require('../designConstants');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var breakpointNames = Object.keys(_designConstants.MEDIA_QUERIES);

/**
 * @param {String} breakpoint - name of breakpoint (for example, 'medium')
 * @returns {String} - state property name (for example, isAtMediumUp)
 */
var getStateNameByBreakpoint = exports.getStateNameByBreakpoint = function getStateNameByBreakpoint(breakpoint) {
	var firstLetter = breakpoint.substr(0, 1).toUpperCase();
	var remainder = breakpoint.substr(1);
	var capitalizedBp = '' + firstLetter + remainder;
	return 'isAt' + capitalizedBp + 'Up';
};

/**
 * @param {Array} mediaQueries - list of matchMedia-created MediaQueryList objects
 * @param {Array} breakpoints - array of breakpoint names that were passed to HOC
 * @returns {Object} - updated `state` object for `withMatchMedia`
 */
var getUpdatedMediaState = exports.getUpdatedMediaState = function getUpdatedMediaState(mediaQueries) {
	return mediaQueries.reduce(function (state, mq, i) {
		state[getStateNameByBreakpoint(breakpointNames[i])] = mq.matches;
		return state;
	}, {});
};

/**
 * Provides viewport-aware props to wrapped component.
 *
 * @param {React.element} WrappedComponent - the component to wrap
 * @param {Array} breakpoints - array of breakpoint names to watch
 */
var withMatchMedia = function withMatchMedia(WrappedComponent) {
	/**
  * @module WithMatchMedia
  */
	var WithMatchMedia = function (_React$Component) {
		_inherits(WithMatchMedia, _React$Component);

		/**
   * @constructor
   * @param {Object} - React element props
   */
		function WithMatchMedia(props) {
			_classCallCheck(this, WithMatchMedia);

			var _this = _possibleConstructorReturn(this, (WithMatchMedia.__proto__ || Object.getPrototypeOf(WithMatchMedia)).call(this, props));

			_this.state = {
				media: props.initialMedia || {}
			};
			_this.mediaQueries = [];

			_this.handleMediaChange = _this.handleMediaChange.bind(_this);
			return _this;
		}

		/**
   * handles media change for _all_ breakpoints configured
   * updates state.media with matched media
   * @returns {undefined}
   */


		_createClass(WithMatchMedia, [{
			key: 'handleMediaChange',
			value: function handleMediaChange() {
				var updated = getUpdatedMediaState(this.mediaQueries);
				this.setState({
					media: _extends({}, this.state.media, updated)
				});
			}

			/**
    * react lifecycle method
    * sets up MediaQueryList listeners
    * @returns {undefined}
    */

		}, {
			key: 'componentDidMount',
			value: function componentDidMount() {
				var _mediaQueries,
				    _this2 = this;

				if (!window.matchMedia) {
					return;
				}

				(_mediaQueries = this.mediaQueries).push.apply(_mediaQueries, _toConsumableArray(breakpointNames.map(function (bp) {
					return window.matchMedia(_designConstants.MEDIA_QUERIES[bp]);
				})));

				// add listeners for every MediaQueryList object
				this.mediaQueries.forEach(function (mq) {
					mq.addListener(_this2.handleMediaChange);
				});

				this.setState({ media: getUpdatedMediaState(this.mediaQueries) });
			}

			/**
    * react lifecycle method
    * clean up media query listeners on unmount
    * @returns {undefined}
    */

		}, {
			key: 'componentWillUnmount',
			value: function componentWillUnmount() {
				var _this3 = this;

				this.mediaQueries.forEach(function (mq) {
					mq.removeListener(_this3.handleMediaChange);
				});
			}

			/**
    * `media` prop is provided to the wrapped component in render().
    *
    * When `this.mediaListeners` detect a media change, `this.state.media` is updated
    * and the component will re-render with correct media-conditional prop values.
    *
    * @returns {React.element}
    */

		}, {
			key: 'render',
			value: function render() {
				var _props = this.props,
				    initialMedia = _props.initialMedia,
				    props = _objectWithoutProperties(_props, ['initialMedia']); // eslint-disable-line no-unused-vars


				return _react2.default.createElement(WrappedComponent, _extends({}, props, { media: this.state.media }));
			}
		}]);

		return WithMatchMedia;
	}(_react2.default.Component);

	var wrappedComponentName = WrappedComponent.displayName || WrappedComponent.name || 'Component';

	WithMatchMedia.WrappedComponent = WrappedComponent;
	WithMatchMedia.displayName = 'WithMatchMedia(' + wrappedComponentName + ')';

	return WithMatchMedia;
};

exports.default = withMatchMedia;
//# sourceMappingURL=withMatchMedia.js.map